@@ -51,38 +51,39 @@ class BuffersManager(AuditManager):
     def get_queryset(self):
         return BufferQuerySet(model=self.model)
 
-    @staticmethod
-    def refreshRows(ids):
+    @classmethod
+    def refreshRows(cls, ids):
         if isinstance(ids, int):
             ids = [ids]
         records = [BuffersManager.getRecord(record) for record in Buffers.objects.filter(id__in=ids)]
         WebSocket.row_refresh_grid(grid_id=settings.GRID_CONSTANTS.refresh_production_buffers_grid_row, records=records)
 
-    @staticmethod
-    def fullRows(suffix=''):
+    @classmethod
+    def fullRows(cls, suffix=''):
         WebSocket.full_refresh_grid(grid_id=f'{settings.GRID_CONSTANTS.refresh_production_buffers_grid}{suffix}')
 
-    @staticmethod
-    def get_buffer_oddment_value(value):
+    @classmethod
+    def get_buffer_oddment_value(cls, value):
         if value is None:
             return 0
         return blinkString(text=DecimalToStr(value), blink=True if value < 0 else False, bold=True, color='green' if value > 0 else 'red')
 
-    @staticmethod
-    def getValue(item, color=None):
+    @classmethod
+    def getValue(cls, item, color=None):
         try:
             buffer = Buffers.objects.get(item=item)
             return buffer.value if buffer.value else 0
         except Buffers.DoesNotExist:
             return None
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             # 'resource_id': record.resource.id if record.resource else None,
             'location_code': record.location_code,
             'location_full_name': record.location_full_name,
             'item_id': record.item.id,
+            'item_name': record.item_name,
             'value': BuffersManager.get_buffer_oddment_value(record.value),
             'value_real': DecimalToStr(record.value),
             'demand_id': record.demand.id if record.demand else None,
@@ -94,10 +95,6 @@ class BuffersManager(AuditManager):
             'color_id': record.color.id if record.color else None,
             'color__color': record.color.color if record.color else None,
             'color__name': record.color.name if record.color else None,
-            'item__STMP_1_id': record.item.STMP_1.id if record.item.STMP_1 else None,
-            'item__STMP_1__value_str': record.item.STMP_1.value_str if record.item.STMP_1 else None,
-            'item__STMP_2_id': record.item.STMP_2.id if record.item.STMP_2 else None,
-            'item__STMP_2__value_str': record.item.STMP_2.value_str if record.item.STMP_2 else None,
 
             'edizm_id': record.edizm.id,
             'edizm__code': record.edizm.code,
@@ -114,14 +111,15 @@ class Buffers(Model):
     demand = ForeignKeyProtect(Demand, null=True, blank=True)
     edizm = ForeignKeyProtect(Ed_izm, null=True, blank=True)
     item = ForeignKeyProtect(Item)
-    last_tech_operation = ForeignKeyProtect(Operations, null=True, blank=True)
+    item_name = NameField(Item)
     last_operation = ForeignKeyProtect(kaf_pas.production.models.operations.Operations, null=True, blank=True)
     last_operation_full_name = NameField(null=True, blank=True)
+    last_tech_operation = ForeignKeyProtect(Operations, null=True, blank=True)
     launch = ForeignKeyProtect(Launches, null=True, blank=True)
-    resource = ForeignKeyProtect(Resource, null=True, blank=True)
     location = ForeignKeyProtect(Locations, null=True, blank=True)
     location_code = NameField(null=True, blank=True)
     location_full_name = NameField(null=True, blank=True)
+    resource = ForeignKeyProtect(Resource, null=True, blank=True)
     value = DecimalField(decimal_places=4, max_digits=19)
 
     objects = BuffersManager()
