@@ -31,16 +31,16 @@ class Tmp_bufferQuerySet(CommonManagetWithLookUpFieldsQuerySet):
 
 class Tmp_bufferManager(CommonManagetWithLookUpFieldsManager):
 
-    @staticmethod
-    def props():
+    @classmethod
+    def props(cls):
         return BitField(flags=(
             ('posting_nakl', 'Оприходования из накладной'),  # 1
             ('posting_uqv', 'Оприходования из минусов'),  # 1
             ('write_off', 'Списания'),  # 2
         ), db_index=True)
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'color__color': record.color.color if record.color else None,
             'color__name': record.color.name if record.color else None,
