@@ -62,6 +62,10 @@ def check_level(
             cycle_ref.append(s)
             s = f'''<pre>Full path Child: {full_path}</pre>'''
             cycle_ref.append(s)
+
+            msq = '<br>'.join(cycle_ref)
+            logger.error(msq)
+            raise Exception(f'<pre>{msq}</pre>')
             # item_refs.delete()
         else:
             if table == 'production_operations':
