@@ -21,8 +21,8 @@ class Ed_izmQuerySet(BaseRefQuerySet, CommonManagetWithLookUpFieldsQuerySet):
 
 class Ed_izmManager(CommonManagetWithLookUpFieldsManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'code': record.code,
@@ -96,8 +96,8 @@ class Ed_izm(BaseRefHierarcy):
 
     objects = Ed_izmManager()
 
-    @staticmethod
-    def root_timevalue():
+    @classmethod
+    def root_timevalue(cls):
         return Ed_izm.objects.get(props=Ed_izm.props.root_timevalue)
 
     def __str__(self):
