@@ -70,14 +70,35 @@ class ItemQuerySet(CommonManagetWithLookUpFieldsQuerySet):
 
 class ItemManager(CommonManagetWithLookUpFieldsManager):
 
+    @classmethod
+    def check_along_items(cls):
+        from kaf_pas.production.models import p_id
+        from kaf_pas.ckk.models.item_refs import Item_refs
+        sql_str = '''select id
+                    from ckk_item
+                    where id not in (select child_id from ckk_item_refs)'''
+
+        with transaction.atomic():
+            with connection.cursor() as cursor:
+                cursor.execute(sql_str)
+                rows = cursor.fetchall()
+
+                for row, in rows:
+                    Item_refs.objects.get_or_create(parent_id=p_id, child_id=row)
+
+
     def createFromRequest(self, request):
         from kaf_pas.ckk.models.item_refs import Item_refs
+        from kaf_pas.production.models import p_id
 
         request = DSRequest(request=request)
         data = request.get_data()
         _data = data.copy()
 
         parent_id = _data.get('id')
+        if parent_id is None:
+            parent_id = p_id
+
         delAttr(_data, 'parent')
         delAttr(_data, 'parent_id')
         delAttr(_data, 'id')
@@ -93,6 +114,7 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
         delAttr(_data, 'relevant')
         delAttr(_data, 'where_from')
         delAttr(_data, 'confirmed')
+        delAttr(_data, 'used')
         setAttr(_data, 'props', props)
         setAttr(_data, 'creator', request.user)
 
@@ -102,9 +124,10 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
         if created:
             logger.debug(f'Added: {res}')
 
-        item_refs, create = Item_refs.objects.get_or_create(parent_id=parent_id, child=res)
-        if create:
-            logger.debug(f'Added item_ref: {item_refs}')
+        if parent_id is not None and created is True:
+            item_refs, create = Item_refs.objects.get_or_create(parent_id=parent_id, child=res)
+            if create:
+                logger.debug(f'Added item_ref: {item_refs}')
 
         res = model_to_dict(res)
 
@@ -116,8 +139,8 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
         data.update(res)
         return data
 
-    @staticmethod
-    def find_item(item):
+    @classmethod
+    def find_item(cls, item):
         if isinstance(item, int):
             item = Item.objects.get(id=item)
         elif not isinstance(item, Item):
@@ -135,8 +158,8 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
 
         return [item for item in item_query]
 
-    @staticmethod
-    def find_item_contains(item):
+    @classmethod
+    def find_item_contains(cls, item):
         if isinstance(item, int):
             item = Item.objects.get(id=item)
         elif not isinstance(item, Item):
@@ -154,8 +177,8 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
 
         return [item for item in item_query]
 
-    @staticmethod
-    def find_item1(**kwargs):
+    @classmethod
+    def find_item1(cls, **kwargs):
         STMP_1 = kwargs.get('STMP_1')
         STMP_2 = kwargs.get('STMP_2')
 
@@ -168,8 +191,8 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
 
         return [item for item in item_query]
 
-    @staticmethod
-    def find_item1_contains(**kwargs):
+    @classmethod
+    def find_item1_contains(cls, **kwargs):
         STMP_1 = kwargs.get('STMP_1')
         STMP_2 = kwargs.get('STMP_2')
         deleted_at = kwargs.get('deleted_at')
@@ -194,8 +217,8 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
 
         return [item for item in item_query]
 
-    @staticmethod
-    def check_4_production(item):
+    @classmethod
+    def check_4_production(cls, item):
         if isinstance(item, int):
             id = item
         elif isinstance(item, Item):
@@ -213,8 +236,8 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
                 qty, = cursor.fetchone()
             return qty > 0
 
-    @staticmethod
-    def delete_recursive(item_id, delete_lines=False, soft_delete=None, user=None, props=TurnBitOn(0, 0), document=None, show_progress=True):
+    @classmethod
+    def delete_recursive(cls, item_id, delete_lines=False, soft_delete=None, user=None, props=TurnBitOn(0, 0), document=None, show_progress=True):
         from kaf_pas.ckk.models.item_document import Item_document
         from kaf_pas.ckk.models.item_history import Item_history
         from kaf_pas.ckk.models.item_image_refs import Item_image_refs
@@ -355,8 +378,8 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
         if item_lotsman_document_cnt > 0:
             refresh_mat_view('kd_lotsman_documents_hierarcy_mview')
 
-    @staticmethod
-    def rec(data):
+    @classmethod
+    def rec(cls, data):
         _data = data.copy()
         relevant = data.get('relevant')
         confirmed = data.get('confirmed')
@@ -411,8 +434,8 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
 
         return _data
 
-    @staticmethod
-    def replaceItems(dropRecords, targetRecord, func_after=None):
+    @classmethod
+    def replaceItems(cls, dropRecords, targetRecord, func_after=None):
         from kaf_pas.ckk.models.item_refs import Item_refs
         from kaf_pas.ckk.models.item_line import Item_line
 
@@ -506,6 +529,17 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
                 # res = []
                 _data = ItemManager.rec(data.copy())
 
+                props = _data.get('props')
+                if _data.get('confirmed') == 'Подтвержден':
+                    props |= Item.props.confirmed
+                elif _data.get('confirmed') == 'Не подтвержден':
+                    props &= ~Item.props.confirmed
+
+                if _data.get('relevant') == 'Актуален':
+                    props |= Item.props.relevant
+                elif _data.get('relevant') == 'Не актуален':
+                    props &= ~Item.props.relevant
+
                 update_dict = dict(
                     STMP_1_id=_data.get('STMP_1_id'),
                     STMP_2_id=_data.get('STMP_2_id'),
@@ -514,21 +548,23 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
                     lotsman_document_id=_data.get('lotsman_document_id'),
                     lotsman_type_id=_data.get('lotsman_type_id'),
                     creator_id=_data.get('creator_id'),
+                    props=props
                 )
                 Item.objects.filter(id=_data.get('id')).update(**update_dict)
 
                 refs_props = _data.get('refs_props')
                 if refs_props is not None:
                     refs_id = _data.get('refs_id')
+
                     if _data.get('used') == True:
                         refs_props |= Item_refs.props.used
-                    else:
+                    elif _data.get('used') == False:
                         refs_props &= ~Item_refs.props.used
 
                     refs_data = dict()
                     setAttr(refs_data, 'props', refs_props)
 
-                    Item_refs.objects.update_or_create(id=refs_id, defaults=refs_data)
+                    Item_refs.objects.filter(id=refs_id).update(**refs_data)
 
                 return _data
 
@@ -584,6 +620,7 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
                         if isinstance(records, list):
                             for record in records:
                                 res, _ = Item_refs.objects1.filter(child_id=record.get('id'), parent_id=record.get('parent_id')).delete_with_checked()
+                                res, _ = Item_line.objects.filter(child_id=record.get('id'), parent_id=record.get('parent_id')).delete()
                     settings.LOCKS.release(key)
 
                 if mode == 'deleteInner':
@@ -597,8 +634,10 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
                         for record in records:
                             if record.get('parent_id') is None:
                                 res, _ = Item_refs.objects1.filter(child_id=record.get('id'), parent__isnull=True).delete_with_checked()
+                                res, _ = Item_line.objects.filter(child_id=record.get('id'), parent__isnull=True).delete()
                             else:
                                 res, _ = Item_refs.objects1.filter(child_id=record.get('id'), parent_id=record.get('parent_id')).delete_with_checked()
+                                res, _ = Item_line.objects.filter(child_id=record.get('id'), parent_id=record.get('parent_id')).delete()
                         settings.LOCKS.release(key)
                         return res
                     settings.LOCKS.release(key)
@@ -645,8 +684,8 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
             setAttr(res, 'value_str', None)
         return res
 
-    @staticmethod
-    def get_verstion(STMP_1, STMP_2, props, version=None, inc=1):
+    @classmethod
+    def get_verstion(cls, STMP_1, STMP_2, props, version=None, inc=1):
         key = 'ItemManager.get_verstion'
         settings.LOCKS.acquire(key)
 
@@ -675,8 +714,8 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
                     version += inc
                 logger.debug(f'version: {version}')
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'STMP_1_id': record.STMP_1.id if record.STMP_1 else None,
@@ -684,6 +723,7 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
             'STMP_2_id': record.STMP_2.id if record.STMP_2 else None,
             'STMP_2__value_str': record.STMP_2.value_str if record.STMP_2 else None,
             'lastmodified': record.lastmodified,
+            'item_name': record.item_name,
             'version': record.version,
             'document_id': record.document.id if record.document else None,
             'document__file_document': record.document.file_document if record.document else None,
@@ -724,8 +764,8 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
                     raise ex
         raise Exception('Not data.')
 
-    @staticmethod
-    def _getQtyChilds(records):
+    @classmethod
+    def _getQtyChilds(cls, records):
         from kaf_pas.ckk.models.item_qty import Item_qty
 
         res = 0
@@ -773,8 +813,8 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
 
 
 class Item_add:
-    @staticmethod
-    def get_prop_field():
+    @classmethod
+    def get_prop_field(cls):
         return BitField(flags=(
             ('relevant', 'Актуальность'),  # 1
             ('from_cdw', 'Получено из чертежа'),  # 2
@@ -846,8 +886,8 @@ class Item(AuditModel):
         else:
             return 'Неизвестен'
 
-    @staticmethod
-    def get_vaslue_str(doc_attr):
+    @classmethod
+    def get_vaslue_str(cls, doc_attr):
         if doc_attr.value_str is None:
             return None
         return doc_attr.value_str.strip() if doc_attr else None
