@@ -19,8 +19,8 @@ class Cdw_Pdf_Item_viewQuerySet(AuditQuerySet):
 
 class Cdw_Pdf_Item_viewManager(AuditManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             "id": record.id,
             "STMP_1_id": record.STMP_1.id if record.STMP_1 else None,
