@@ -17,8 +17,8 @@ class Item_Complex_viewQuerySet(AuditQuerySet):
 
 class Item_Complex_viewManager(AuditManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             "id": record.id,
             "STMP_1_id": record.STMP_1.id if record.STMP_1 else None,
