@@ -46,8 +46,8 @@ class Item_flat_viewQuerySet(AuditQuerySet):
 
 class Item_flat_viewManager(AuditManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'confirmed': record.confirmed,
             'deliting': record.deliting,
