@@ -17,14 +17,14 @@ logger = logging.getLogger(__name__)
 
 
 class Item_image_refsManager(AuditManager):
-    @staticmethod
-    def props():
+    @classmethod
+    def props(cls):
         return BitField(flags=(
             ('useinprint', 'Выводим в печатную форму'),  # 1
         ), default=0, db_index=True)
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         if settings.ENABLE_FILE_VIEW:
 
             file_document_names = os.path.split(record.thumb.document.file_document) if record.thumb is not None and record.thumb.document is not None else None
