@@ -15,8 +15,8 @@ logger = logging.getLogger(__name__)
 
 
 class Item_image_refs_viewManager(AuditManager):
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         if settings.ENABLE_FILE_VIEW:
 
             file_document_names = os.path.split(record.thumb.document.file_document) if record.thumb is not None and record.thumb.document is not None else None
