@@ -66,7 +66,8 @@ class Item_lineQuerySet(AuditQuerySet):
         setAttr(kwargs, 'section_num', section_num)
         delAttr(kwargs, 'confirmed')
         delAttr(kwargs, 'edizm__name')
-        delAttr(kwargs, '_name')
+        delAttr(kwargs, 'deleted')
+        kwargs = self.delete_underscore_element(kwargs)
         return super().update(**kwargs)
 
     def update_or_create(self, defaults=None, **kwargs):
@@ -87,13 +88,13 @@ class Item_lineManager(TreeAuditModelManager):
     def get_queryset(self):
         return Item_lineQuerySet(self.model, using=self._db)
 
-    @staticmethod
-    def section_num(section):
+    @classmethod
+    def section_num(cls, section):
         sorted_section = {"Документация": 0, "Комплексы": 1, "Сборочные единицы": 2, "Детали": 3, "Стандартные изделия": 4, "Прочие изделия": 5, "Материалы": 6, "Комплекты": 7}
         return sorted_section.get(section)
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'child_id': record.child.id if record.child else None,
@@ -134,8 +135,8 @@ class Item_lineManager(TreeAuditModelManager):
         }
         return res
 
-    @staticmethod
-    def getIcon(record):
+    @classmethod
+    def getIcon(cls, record):
         if record.isFolder:
             return 'folder_256.png'
         elif record.section is not None:
@@ -374,6 +375,14 @@ class Item_lineManager(TreeAuditModelManager):
                     if record.get("parent_id") is None:
                         raise Exception('Верхний уровень не подлежит внесению в детализацию.')
 
+                    item_line_query = Item_line.objects.filter(
+                        parent_id=record.get("parent_id"),
+                        child_id=record.get("id"))
+
+                    if item_line_query.count() > 0:
+                        res = item_line_query[0]
+                        break
+
                     query = Item_line_view.objects.filter(
                         SPC_CLM_NAME_id=record.get('STMP_1_id'),
                         SPC_CLM_MARK_id=record.get('STMP_2_id')
@@ -451,12 +460,31 @@ class Item_lineManager(TreeAuditModelManager):
                 elif mode == 'visible':
                     pass
                 else:
-                    for item_line in super().filter(id=id).select_for_update():
+                    for item_line in super().filter(id=id):
                         Item_refs.objects1.filter(parent=item_line.parent, child=item_line.child).delete_with_checked()
-                        item_line.delete()
+                        Item_line.objects.filter(id=item_line.id).delete()
                         res += 1
         return res
 
+    def checkNameMarkFromRequest(self, request, removed=None, ):
+        from kaf_pas.production.models.launch_item_line import Launch_item_line
+
+        request = DSRequest(request=request)
+        data = request.get_data()
+        records = data.get('records')
+        res = 0
+        with transaction.atomic():
+            for record in records:
+                child_id = record.get('child_id')
+                parent_id = record.get('parent_id')
+                id = record.get('id')
+                refs_id = record.get('refs_id')
+
+                item = Item.objects.get(id=child_id)
+                res = Item_line.objects.filter(id=id, child_id=child_id, parent_id=parent_id).update(SPC_CLM_NAME=item.STMP_1, SPC_CLM_MARK=item.STMP_2)
+                res += Launch_item_line.objects.filter(id=refs_id, child_id=child_id, parent_id=parent_id).update(SPC_CLM_NAME=item.STMP_1, SPC_CLM_MARK=item.STMP_2)
+        return res
+
 
 class Item_line(AuditModel):
     parent = ForeignKeyProtect(Item, verbose_name='Товарная позиция', related_name='item_parent')
@@ -486,6 +514,32 @@ class Item_line(AuditModel):
 
     objects = Item_lineManager()
 
+    @classmethod
+    def checkVariants(cls, parent, child):
+        item = Item.objects.get(id=child.id)
+        _query = cls.objects.filter(parent=parent)
+
+        if item.STMP_2 is None:
+            query = _query.filter(SPC_CLM_NAME__value_str__delete_dbl_spaces=delete_dbl_spaces(item.STMP_1.value_str))
+        elif item.STMP_1 is None:
+            query = _query.filter(SPC_CLM_MARK__value_str__delete_dbl_spaces=delete_dbl_spaces(item.STMP_2.value_str))
+        else:
+            query = _query.filter(SPC_CLM_NAME__value_str__delete_dbl_spaces=delete_dbl_spaces(item.STMP_1.value_str),
+                                 SPC_CLM_MARK__value_str__delete_dbl_spaces=delete_dbl_spaces(item.STMP_2.value_str))
+
+        res = 0
+        if query.count() > 0:
+            res = query.update(child=child)
+            logger.debug(f'Updated: {res}')
+        elif item.STMP_2 is not None:
+            query = _query.filter(SPC_CLM_MARK__value_str__delete_dbl_spaces=delete_dbl_spaces(item.STMP_2.value_str))
+            if query.count() > 0:
+                res = query.update(child=child)
+            logger.debug(f'Updated: {res}')
+        return res
+
+    # К4322.50.14.010-04
+    # К4322.50.14.010-04
     @property
     def qty(self):
         if self.SPC_CLM_COUNT is None:
