@@ -16,8 +16,8 @@ class Item_locationQuerySet(AuditQuerySet):
 
 class Item_locationManager(AuditManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'editing': record.editing,
             'deliting': record.deliting,
