@@ -4,7 +4,6 @@ from django.conf import settings
 from django.db.models import BigIntegerField, BooleanField, PositiveIntegerField
 
 from isc_common import setAttr, delAttr
-from isc_common.auth.models.user import User
 from isc_common.datetime import DateToStr
 from isc_common.fields.code_field import CodeField
 from isc_common.fields.name_field import NameField
@@ -34,15 +33,15 @@ class Item_operations_viewQuerySet(AuditQuerySet):
 
 
 class Item_operations_viewManager(AuditManager):
-    @staticmethod
-    def refreshRows(ids):
+    @classmethod
+    def refreshRows(cls, ids):
         if isinstance(ids, int):
             ids = [ids]
         records = [Item_operations_viewManager.getRecord(record) for record in Item_operations_view.objects.filter(id__in=ids)]
         WebSocket.row_refresh_grid(grid_id=settings.GRID_CONSTANTS.refresh_production_order_item_grid_row, records=records)
 
-    @staticmethod
-    def fullRows(suffix=''):
+    @classmethod
+    def fullRows(cls, suffix=''):
         WebSocket.full_refresh_grid(grid_id=f'{settings.GRID_CONSTANTS.refresh_production_order_item_grid}{suffix}')
 
     def updateFromRequest(self, request, removed=None, function=None):
@@ -78,8 +77,8 @@ class Item_operations_viewManager(AuditManager):
 
         return data
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'confirmed': record.confirmed,
             # 'creator_id': record.creator.id,
@@ -109,9 +108,10 @@ class Item_operations_viewManager(AuditManager):
         # print(res)
         return DelProps(res)
 
-    @staticmethod
-    def getRecord1(record):
-        item_refs = Item_refs.objects1.get(id=record.refs_id)
+    @classmethod
+    def getRecord1(cls, record):
+        item_refs = list(Item_refs.objects1.filter(id=record.refs_id))
+
         res = {
             'confirmed': record.confirmed,
             # 'creator_id': record.creator.id,
@@ -127,14 +127,14 @@ class Item_operations_viewManager(AuditManager):
             'props': record.props,
             'qty_operations': record.qty_operations,
             'refs_id': record.refs_id,
-            'refs_props': item_refs.props,
+            'refs_props': item_refs[0].props if list(item_refs) == 1 else 0,
             'relevant': record.relevant,
             'section': record.section,
             'STMP_1__value_str': record.STMP_1.value_str if record.STMP_1 else None,
             'STMP_1_id': record.STMP_1.id if record.STMP_1 else None,
             'STMP_2__value_str': record.STMP_2.value_str if record.STMP_2 else None,
             'STMP_2_id': record.STMP_2.id if record.STMP_2 else None,
-            'used': item_refs.props.used,
+            'used': item_refs[0].props.used if len(item_refs) == 1 else False,
             'version': record.version,
             'where_from': record.where_from,
         }
