@@ -24,8 +24,8 @@ class Item_qty_viewQuerySet(AuditQuerySet):
 
 class Item_qty_viewManager(AuditManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'editing': record.editing,
