@@ -105,29 +105,29 @@ class Locations_usersManager(AuditManager):
 
             return res
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
-            'id': record.id,
-            'user_id': record.user.id,
-            'user__username': record.user.username,
-            'user__first_name': record.user.first_name,
-            'user__last_name': record.user.last_name,
-            'user__email': record.user.email,
-            'user__middle_name': record.user.middle_name,
             'compulsory_reading': record.props.compulsory_reading,
-            'resiver_production_order': record.props.resiver_production_order,
-            'props': record.props,
-            'editing': record.editing,
             'deliting': record.deliting,
+            'editing': record.editing,
+            'id': record.id,
             'location_id': record.location.id,
             'location_position': record.location_position,
             'parent_id': record.parent.id if record.parent else None,
+            'props': record.props,
+            'resiver_production_order': record.props.resiver_production_order,
+            'user__email': record.user.email,
+            'user__first_name': record.user.first_name,
+            'user__last_name': record.user.last_name,
+            'user__middle_name': record.user.middle_name,
+            'user__username': record.user.username,
+            'user_id': record.user.id,
         }
         return DelProps(res)
 
-    @staticmethod
-    def getRecord1(record):
+    @classmethod
+    def getRecord1(cls, record):
         res = {
             'location_id': record.location.id,
         }
@@ -153,6 +153,28 @@ class Locations_users(Hierarcy):
             res.append(f'{item.location.full_name} : {item.position.name}')
         return ', '.join(res)
 
+    @classmethod
+    def user_location_ids(cls, user):
+        if isinstance(user, int):
+            return list(set(map(lambda x: x.location.id, cls.objects.filter(user_id=user))))
+        elif isinstance(user, User):
+            return list(set(map(lambda x: x.location.id, cls.objects.filter(user=user))))
+        elif isinstance(user, list):
+            return list(set(map(lambda x: x.location.id, cls.objects.filter(user_id__in=user))))
+        else:
+            raise Exception(f'{user} must be int or User')
+
+    @classmethod
+    def location_user_ids(cls, location):
+        if isinstance(location, int):
+            return list(set(map(lambda x: x.user.id, cls.objects.filter(location_id=location))))
+        elif isinstance(location, Locations):
+            return list(set(map(lambda x: x.user.id, cls.objects.filter(location=location))))
+        elif isinstance(location, list):
+            return list(set(map(lambda x: x.user.id, cls.objects.filter(location_id__in=location))))
+        else:
+            raise Exception(f'{location} must be int or Locations')
+
     objects = Locations_usersManager()
 
     def __str__(self):
