@@ -1,6 +1,6 @@
 import logging
 
-from django.db.models import BooleanField, SmallIntegerField
+from django.db.models import BooleanField, SmallIntegerField, TextField
 from django.forms import model_to_dict
 
 from clndr.models.calendars import Calendars
@@ -32,24 +32,25 @@ class Locations_viewQuerySet(BaseRefQuerySet, CommonManagetWithLookUpFieldsQuery
 
 class Locations_viewManager(CommonManagetWithLookUpFieldsManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
-            'id': record.id,
-            'code': record.code,
-            'name': record.name,
-            'full_name': record.full_name,
-            'color': record.color,
-            'isFolder': record.isFolder,
-            'description': record.description,
-            'workshop_id': record.workshop.id if record.workshop else None,
-            'parent_id': record.parent.id if record.parent else None,
-            'calendar_id': record.calendar.id if record.calendar else None,
             'calendar__full_name': record.calendar.full_name if record.calendar else None,
-            'editing': record.editing,
+            'calendar_id': record.calendar.id if record.calendar else None,
+            'code': record.code,
+            'color': record.color,
             'deliting': record.deliting,
+            'description': record.description,
+            'editing': record.editing,
+            'full_name': record.fullname,
+            'grouping_production_orders': record.props.grouping_production_orders,
+            'id': record.id,
+            'isFolder': record.isFolder,
             'isWorkshop': record.props.isWorkshop,
+            'name': record.name,
+            'parent_id': record.parent.id if record.parent else None,
             'props': record.props,
+            'workshop_id': record.workshop.id if record.workshop else None,
         }
         return DelProps(res)
 
@@ -62,7 +63,8 @@ class Locations_view(BaseRefHierarcy):
     color = CodeField()
     isFolder = BooleanField()
     props = LocationsManager.props()
-    workshop = ForeignKeyProtect(Locations, null=True, blank=True)
+    workshop = ForeignKeyProtect(Locations)
+    fullname = TextField()
 
     objects = Locations_viewManager()
 
