@@ -14,8 +14,8 @@ class Material_askonQuerySet(AuditQuerySet):
 
 class Material_askonManager(AuditManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'field0': record.field0,
