@@ -91,8 +91,8 @@ class Material_paramsQuerySet(CommonManagetWithLookUpFieldsQuerySet):
 
 class Material_paramsManager(CommonManagetWithLookUpFieldsManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'materials_type_id': record.materials_type.id,
