@@ -14,8 +14,8 @@ class Material_typeQuerySet(BaseRefQuerySet):
 
 class Material_typeManager(BaseRefManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'code': record.code,
