@@ -14,8 +14,8 @@ class Material_type_viewQuerySet(BaseRefQuerySet):
 
 class Material_type_viewManager(BaseRefManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'code': record.code,
