@@ -13,8 +13,8 @@ class StatusQuerySet(AuditQuerySet):
 
 class StatusManager(AuditManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             "id": record.id,
             "code": record.code,
