@@ -60,3 +60,7 @@ def Item_CheckRecursives(request):
 @JsonResponseWithException()
 def GetQtyChilds(request):
     return JsonResponse(DSResponse(request=request, data=Item.objects.getQtyChilds(request=request), status=RPCResponseConstant.statusSuccess).response)
+
+@JsonResponseWithException()
+def GetGrouping(request):
+    return JsonResponse(DSResponse(request=request, data=Item.objects.getGrouping(request=request), status=RPCResponseConstant.statusSuccess).response)
