@@ -16,8 +16,8 @@ class User_agg_viewQuerySet(AuditQuerySet):
 
 class User_agg_viewManager(AuditManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'username': record.username,
