@@ -13,8 +13,8 @@ class User_positionsQuerySet(AuditQuerySet):
 
 class User_positionsManager(AuditManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'code': record.code,
