@@ -4,6 +4,7 @@ from django.core.management import BaseCommand
 from django.db import transaction
 from tqdm import tqdm
 
+from isc_common.auth.models.user import User
 from isc_common.logger.Logger import Logger
 from kaf_pas.ckk.models.attr_type import Attr_type
 from kaf_pas.kd.models.documents import Documents
@@ -27,6 +28,6 @@ class Command(BaseCommand):
 
             pbar = tqdm(total=len(pdfs))
             for document in pdfs:
-                self.documentManagerExt.make_pdf(document=document, STMP_1_type=STMP_1_type, STMP_2_type=STMP_2_type)
+                self.documentManagerExt.make_pdf(document=document, STMP_1_type=STMP_1_type, STMP_2_type=STMP_2_type, user=User.objects.get(id=2))
                 pbar.update()
             pbar.close()
