@@ -4,6 +4,7 @@ from django.core.management import BaseCommand
 from django.db import transaction
 from tqdm import tqdm
 
+from isc_common.auth.models.user import User
 from isc_common.logger.Logger import Logger
 from kaf_pas.kd.models.documents import Documents
 from kaf_pas.kd.models.documents_ext import DocumentManagerExt
@@ -23,7 +24,7 @@ class Command(BaseCommand):
         with transaction.atomic():
             pbar = tqdm(total=len(spws))
             for document in spws:
-                self.documentManagerExt.make_spw(document=document)
+                self.documentManagerExt.make_spw(document=document, user=User.objects.get(id=2))
                 pbar.update()
 
             pbar.close()
