@@ -20,8 +20,8 @@ class Cdw_attrsManager(Document_attributes_viewManager):
     def get_queryset(self):
         return Cdw_attrsQuerySet(self.model, using=self._db)
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             "id": record.id,
             "attr_type_id": record.attr_type.id,
