@@ -44,8 +44,8 @@ class Document_attr_cross1QuerySet(QuerySet):
 
 class Document_attr_cross1Manager(Manager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'editing': record.editing,
