@@ -25,8 +25,8 @@ class Document_attrs_viewManager(Document_attributesManager):
     def get_queryset(self):
         return Document_attrs_viewQuerySet(self.model, using=self._db)
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             "id": record.id,
             "attr_type_id": record.attr_type.id,
