@@ -29,8 +29,8 @@ class DocumentManager(CommonManagetWithLookUpFieldsManager):
     def get_queryset(self):
         return DocumentQuerySet(self.model, using=self._db)
 
-    @staticmethod
-    def get_m_view():
+    @classmethod
+    def get_m_view(cls):
         sql_str = '''SELECT kd.id,
                             kd.editing,
                             kd.deliting,
@@ -61,8 +61,8 @@ class DocumentManager(CommonManagetWithLookUpFieldsManager):
         drop_mat_view(mat_view_name='kd_documents_mview')
         create_tmp_mat_view(sql_str=sql_str, mat_view_name='kd_documents_mview', indexes=['attr_type_id', 'path_id', 'STMP_1_id', 'STMP_2_id'])
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             "id": record.id,
             "path_id": record.path.id,
@@ -215,8 +215,8 @@ class DocumentManager(CommonManagetWithLookUpFieldsManager):
 
         return data
 
-    @staticmethod
-    def delete(id, user):
+    @classmethod
+    def delete(cls, id, user):
         from isc_common.auth.models.user import User
         from kaf_pas.ckk.models.item import Item
         from kaf_pas.ckk.models.item import ItemManager
@@ -313,8 +313,8 @@ class DocumentManager(CommonManagetWithLookUpFieldsManager):
 class Documents(AuditModel):
     path = ForeignKeyProtect(Pathes, verbose_name='Путь к документу')
     attr_type = ForeignKeyProtect(Attr_type, verbose_name='Тип документа')
-    file_document = TextField(verbose_name='Полный путь к файлу', db_index=True)
-    file_size = PositiveIntegerField(verbose_name='Размер файла')
+    file_document = TextField(verbose_name='Полный путь к файлу', db_index=True, null=True, blank=True)
+    file_size = PositiveIntegerField(verbose_name='Размер файла', null=True, blank=True)
     file_modification_time = DateTimeField(verbose_name='Дата время поcледнего модификации документа', null=True, blank=True, db_index=True)
     file_access_time = DateTimeField(verbose_name='Дата время поcледнего доступа к документу', null=True, blank=True, db_index=True)
     file_change_time = DateTimeField(verbose_name='Дата время изменнения документа', null=True, blank=True, db_index=True)
