@@ -14,8 +14,8 @@ class Documents_historyQuerySet(AuditQuerySet):
 
 class Documents_historyManager(AuditManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'editing': record.editing,
