@@ -16,8 +16,8 @@ class Documents_thumb10_preview_paramsQuerySet(AuditQuerySet):
 
 class Documents_thumb10_preview_paramsManager(AuditManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'editing': record.editing,
