@@ -10,29 +10,12 @@ logger = logging.getLogger(__name__)
 
 
 class Lotsman_document_attr_cross1QuerySet(QuerySet):
-    def delete(self):
-        return super().delete()
-
-    def create(self, **kwargs):
-        return super().create(**kwargs)
-
-    def update(self, **kwargs):
-        return super().create(**kwargs)
-
-    def update_or_create(self, defaults=None, **kwargs):
-        return super().update_or_create(**kwargs, defaults=defaults)
-
-    def get_or_create(self, defaults=None, **kwargs):
-        return super().get_or_create(**kwargs, defaults=defaults)
-
-    def filter(self, *args, **kwargs):
-        return super().filter(*args, **kwargs)
-
+    pass
 
 class Lotsman_document_attr_cross1Manager(Manager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'editing': record.editing,
