@@ -22,8 +22,8 @@ class Lotsman_documents_hierarcyQuerySet(AuditQuerySet):
 
 class Lotsman_documents_hierarcyManager(AuditManager):
 
-    @staticmethod
-    def delete(id, user):
+    @classmethod
+    def delete(cls, id, user):
         from isc_common.auth.models.user import User
         from kaf_pas.ckk.models.item import Item
         from kaf_pas.ckk.models.item import ItemManager
@@ -54,8 +54,8 @@ class Lotsman_documents_hierarcyManager(AuditManager):
         settings.LOCKS.release(key)
         return res
 
-    @staticmethod
-    def delete_file(id, user):
+    @classmethod
+    def delete_file(cls, id, user):
         from isc_common.auth.models.user import User
         from kaf_pas.kd.models.documents_thumb import Documents_thumb
         from kaf_pas.kd.models.documents_thumb10 import Documents_thumb10
@@ -77,15 +77,15 @@ class Lotsman_documents_hierarcyManager(AuditManager):
         settings.LOCKS.release(key)
         return res
 
-    @staticmethod
-    def get_props():
+    @classmethod
+    def get_props(cls):
         return BitField(flags=(
             ('relevant', 'Актуальность'),
             ('beenItemed', 'Был внесен в состав изделий'),
         ), default=1, db_index=True)
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'editing': record.editing,
