@@ -1,6 +1,6 @@
 import logging
 
-from django.db.models import TextField
+from django.db.models import TextField, BigIntegerField
 
 from isc_common.fields.related import ForeignKeyProtect
 from isc_common.models.audit import AuditModel, AuditManager, AuditQuerySet
@@ -15,8 +15,8 @@ class Lotsman_documents_hierarcy_filesQuerySet(AuditQuerySet):
 
 class Lotsman_documents_hierarcy_filesManager(AuditManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'editing': record.editing,
@@ -30,6 +30,7 @@ class Lotsman_documents_hierarcy_filesManager(AuditManager):
 
 class Lotsman_documents_hierarcy_files(AuditModel):
     lotsman_document = ForeignKeyProtect(Lotsman_documents_hierarcy)
+    size = BigIntegerField(null=True, blank=True)
     path = TextField()
 
     objects = Lotsman_documents_hierarcy_filesManager()
