@@ -75,8 +75,8 @@ class Lotsman_documents_hierarcy_viewQuerySet(AuditQuerySet):
 
 class Lotsman_documents_hierarcy_viewManager(AuditManager):
 
-    @staticmethod
-    def getIcon(record):
+    @classmethod
+    def getIcon(cls, record):
         if record.attr_name is not None:
             _section = record.attr_name.lower()
             if _section == 'документация':
@@ -108,8 +108,8 @@ class Lotsman_documents_hierarcy_viewManager(AuditManager):
         else:
             return 'question.png'
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         def set_document_icon(record):
             from kaf_pas.kd.models.lotsman_documents_hierarcy_files import Lotsman_documents_hierarcy_files
             setAttr(record, 'isLoadedPict', Lotsman_documents_hierarcy_files.objects.filter(lotsman_document_id=record.get('id')).count() > 0)
