@@ -30,8 +30,8 @@ class PathesQuerySet(CommonManagetWithLookUpFieldsQuerySet):
 
 
 class PathesManager(CommonManagetWithLookUpFieldsManager):
-    @staticmethod
-    def props():
+    @classmethod
+    def props(cls):
         return BitField(flags=(
             ('enable_upload', 'Директория для закачки'),
         ), default=1, db_index=True)
@@ -39,8 +39,8 @@ class PathesManager(CommonManagetWithLookUpFieldsManager):
     def get_queryset(self):
         return PathesQuerySet(self.model, using=self._db)
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             "id": record.id,
             "path": record.path,
@@ -75,11 +75,11 @@ class PathesManager(CommonManagetWithLookUpFieldsManager):
 
             if path != '':
                 if with_out_last:
-                    path = path.split(self.sep)[: - 1]
+                    path_items = path.split(self.sep)[: - 1]
                 else:
-                    path = path.split(self.sep)
+                    path_items = path.split(self.sep)
 
-                for path_item in path:
+                for path_item in path_items:
                     if path_item:
                         alive_only = self.alive_only
                         try:
@@ -114,11 +114,11 @@ class PathesManager(CommonManagetWithLookUpFieldsManager):
 
             if path != '':
                 if with_out_last:
-                    path = path.split(self.sep)
+                    path_items = path.split(self.sep)
                 else:
-                    path = path.split(self.sep)
+                    path_items = path.split(self.sep)
 
-                for path_item in path:
+                for path_item in path_items:
                     if path_item:
                         alive_only = self.alive_only
                         try:
@@ -151,7 +151,6 @@ class PathesManager(CommonManagetWithLookUpFieldsManager):
 
         ids = request.GET.getlist('ids')
         request = DSRequest(request=request)
-        user_id = request.user_id
 
         res = 0
         count = 0
@@ -186,7 +185,7 @@ class PathesManager(CommonManagetWithLookUpFieldsManager):
                                 upload.delete()
 
                             for document in Documents.objects.filter(path_id=path.id):
-                                count, lotsman_count = DocumentManager.delete(document.id, User.objects.get(id=user_id))
+                                count, lotsman_count = DocumentManager.delete(document.id, request.user)
 
                             res += super().filter(id=path.id).delete()[0]
                             logger.debug(f'Deleted: {res}')
@@ -212,25 +211,13 @@ class PathesManager(CommonManagetWithLookUpFieldsManager):
         except Pathes.DoesNotExist:
             return None
 
-    # def get_drive(self, id):
-    #     try:
-    #         path = self.get(id=id)
-    #         if path.drive:
-    #             return path.drive
-    #         elif path.parent:
-    #             return self.get_drive(path.parent.id)
-    #         else:
-    #             return path.drive
-    #     except Pathes.DoesNotExist:
-    #         return None
-
 
 class Pathes(Hierarcy):
+    attr_type = ForeignKeyProtect(Attr_type, verbose_name='Атрибут', null=True, blank=True)
     drive = CharField(verbose_name='Диск', max_length=10, null=True, blank=True)
     path = TextField(verbose_name="Путь")
-    virt_path = TextField(verbose_name="Мнимый путь", null=True, blank=True)
-    attr_type = ForeignKeyProtect(Attr_type, verbose_name='Атрибут', null=True, blank=True)
     props = PathesManager.props()
+    virt_path = TextField(verbose_name="Мнимый путь", null=True, blank=True)
 
     @property
     def sep(self):
@@ -285,7 +272,7 @@ class Pathes(Hierarcy):
             return self.absolute_path
 
     def __str__(self):
-        return f"{self.absolute_path}"
+        return f"ID: {self.id}, drive: {self.drive}, virt_path: {self.virt_path}, attr_type: [{self.attr_type}] absolute_path: {self.absolute_path}"
 
     objects = PathesManager()
     objects_tree = TreeAuditModelManager()
