@@ -21,8 +21,8 @@ class Spw_attrsQuerySet(Document_attributesQuerySet):
         setAttr(kwargs, 'attr_type__code__contains', 'SPC')
         return super().filter(*args, **kwargs)
 
-    @staticmethod
-    def make_specification(queryResult):
+    @classmethod
+    def make_specification(cls, queryResult):
         key = 'Spw_attrsQuerySet.make_specification'
         settings.LOCKS.acquire(key)
         res = []
@@ -75,8 +75,8 @@ class Spw_attrsQuerySet(Document_attributesQuerySet):
 
 class Spw_attrsManager(Document_attributes_viewManager):
 
-    @staticmethod
-    def rec_document_attr(document_id, attr_type_id, code, attr_type__code, value_str, position, section, subsection):
+    @classmethod
+    def rec_document_attr(cls, document_id, attr_type_id, code, attr_type__code, value_str, position, section, subsection):
         from kaf_pas.kd.models.document_attr_cross import Document_attr_cross
         from kaf_pas.kd.models.documents import Documents
 
@@ -125,8 +125,8 @@ class Spw_attrsManager(Document_attributes_viewManager):
             return res
         settings.LOCKS.release(key)
 
-    @staticmethod
-    def update_rec_spesification(data):
+    @classmethod
+    def update_rec_spesification(cls, data):
         key = f'''Spw_attrsManager.update_rec_spesification_{data.get('document_id')}'''
         settings.LOCKS.acquire(key)
         with transaction.atomic():
@@ -284,8 +284,8 @@ class Spw_attrsManager(Document_attributes_viewManager):
     def get_queryset(self):
         return Spw_attrsQuerySet(self.model, using=self._db)
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             "id": record.id,
             "document_id": record.document.id,
@@ -304,8 +304,8 @@ class Spw_attrsManager(Document_attributes_viewManager):
         }
         return res
 
-    @staticmethod
-    def try_delete_attribute(id):
+    @classmethod
+    def try_delete_attribute(cls, id):
         Document_attributes.objects.filter(id=id).delete()
 
 
