@@ -4,11 +4,13 @@ from bitfield import BitField
 from django.conf import settings
 from django.db import transaction
 
+from isc_common import delAttr
 from isc_common.bit import TurnBitOn
 from isc_common.common import blinkString
 from isc_common.common.mat_views import refresh_mat_view
 from isc_common.datetime import DateTimeToStr
 from isc_common.fields.related import ForeignKeyProtect
+from isc_common.http.DSRequest import DSRequest
 from isc_common.models.audit import AuditModel, AuditManager, AuditQuerySet
 from isc_common.number import DelProps
 from isc_common.progress import managed_progress, ProgressDroped, progress_deleted
@@ -18,23 +20,19 @@ logger = logging.getLogger(__name__)
 
 
 class UploadesQuerySet(AuditQuerySet):
-    def create(self, **kwargs):
-        return super().create(**kwargs)
-
-    def filter(self, *args, **kwargs):
-        return super().filter(*args, **kwargs)
+    pass
 
 
 class UploadesManager(AuditManager):
 
-    @staticmethod
-    def props():
+    @classmethod
+    def props(cls):
         return BitField(flags=(
             ('confirmed', 'Подтверждено'),
         ), default=0, db_index=True)
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'lastmodified': record.lastmodified,
@@ -50,8 +48,8 @@ class UploadesManager(AuditManager):
     def get_queryset(self):
         return UploadesQuerySet(self.model, using=self._db)
 
-    @staticmethod
-    def del_upload(id, user, doc_cnt=0, lotsman_cnt=0, document_id=None, last_step=False):
+    @classmethod
+    def del_upload(cls, id, user, doc_cnt=0, lotsman_cnt=0, document_id=None, last_step=False):
         from kaf_pas.ckk.models.item import Item
         from kaf_pas.ckk.models.item import ItemManager
         from kaf_pas.ckk.models.item_document import Item_document
