@@ -15,8 +15,8 @@ class Uploades_documentsQuerySet(AuditQuerySet):
 
 class Uploades_documentsManager(AuditManager):
 
-    @staticmethod
-    def refreshRows(ids, user):
+    @classmethod
+    def refreshRows(cls, ids, user):
         from kaf_pas.planing.models.production_order import Production_orderManager
         from isc_common.ws.webSocket import WebSocket
         from django.conf import settings
@@ -26,8 +26,8 @@ class Uploades_documentsManager(AuditManager):
 
         WebSocket.row_refresh_grid(grid_id=settings.GRID_CONSTANTS.refresh_uploades_documents_grid_row, records=records)
 
-    @staticmethod
-    def fullRows(suffix=''):
+    @classmethod
+    def fullRows(cls, suffix=''):
         from isc_common.ws.webSocket import WebSocket
         from django.conf import settings
 
@@ -62,8 +62,8 @@ class Uploades_documentsManager(AuditManager):
                 lotsman_cnt += _lotsman_cnt
         return res
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'document_id': record.document.id,
