@@ -16,8 +16,8 @@ class Uploades_logQuerySet(AuditQuerySet):
 
 class Uploades_logManager(AuditManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'upload_id': record.upload.id,
