@@ -11,4 +11,4 @@ logger = logging.getLogger(__name__)
 class Command(BaseCommand):
     def handle(self, *args, **options):
         with transaction.atomic():
-            Production_orderManager.ungrouping(location_id=117, users=Production_orderManager.get_use_4_grouping_message(location_id=117))
+            Production_orderManager.ungrouping(location_id=12, launch=349)
