@@ -13,8 +13,8 @@ class LevelsQuerySet(BaseRefQuerySet):
 
 class LevelsManager(BaseRefManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'code': record.code,
