@@ -14,8 +14,8 @@ class Operation_colorQuerySet(BaseOperationQuerySet):
 
 class Operation_colorManager(AuditManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'editing': record.editing,
