@@ -4,6 +4,7 @@ from django.db.models import Model, DecimalField, DateTimeField, BigIntegerField
 
 from isc_common.fields.related import ForeignKeyProtect
 from isc_common.http.DSRequest import DSRequest
+from isc_common.json import StrToJson
 from isc_common.models.audit import AuditManager, AuditQuerySet
 from isc_common.models.standard_colors import Standard_colors
 from isc_common.number import DecimalToStr
@@ -23,6 +24,10 @@ class Operation_color_viewQuerySet(AuditQuerySet):
 
         records = data.get('records')
         parentId = data.get('parentId')
+        productionOrderlaunchRecord = data.get('productionOrderlaunchRecord')
+        childs = []
+        if productionOrderlaunchRecord is not None:
+            childs = productionOrderlaunchRecord.get('childs')
 
         res = []
         if isinstance(records, list) and len(records) > 0 and isinstance(parentId, int):
@@ -34,6 +39,21 @@ class Operation_color_viewQuerySet(AuditQuerySet):
                 production_operation_num=record.get('production_operation_num') - 1
             )
 
+            if prev.count() > 0:
+                prev = prev[0]
+                if prev.production_operation_is_launched:
+                    res = [Operation_color_viewManager.getRecord(record) for record in Operation_color_view.objects.filter(operation_id=prev.id)]
+        elif len(childs) > 0:
+            this = Production_order_opers.objects.get(
+                id=childs[0]
+            )
+
+            prev = Production_order_opers.objects.filter(
+                parent_id=productionOrderlaunchRecord.get('id_real'),
+                deleted_at=None,
+                production_operation_num=this.production_operation_num - 1
+            )
+
             if prev.count() > 0:
                 prev = prev[0]
                 if prev.production_operation_is_launched:
@@ -60,8 +80,8 @@ class Operation_color_viewQuerySet(AuditQuerySet):
 
 class Operation_color_viewManager(AuditManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'demand_id': record.demand.id if record.demand else None,
