@@ -16,15 +16,15 @@ class Operation_executorQuerySet(BaseOperationQuerySet):
 
 class Operation_executorManager(AuditManager):
 
-    @staticmethod
-    def props():
+    @classmethod
+    def props(cls):
         return BitField(flags=(
             ('relevant', 'Актуальность'),  # 1
             ('rearrange', 'Переадресованный'),  # 1
         ), default=1, db_index=True)
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'editing': record.editing,
