@@ -49,8 +49,8 @@ class Operation_historyQuerySet(AuditHistoryQuerySet):
 
 class Operation_historyManager(AuditHistoryManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'code': record.code,
