@@ -24,8 +24,8 @@ class Operation_item_viewQuerySet(BaseOperationQuerySet):
 
 class Operation_item_viewManager(CommonManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'editing': record.editing,
