@@ -14,8 +14,8 @@ class Operation_launch_itemQuerySet(BaseOperationQuerySet):
 
 class Operation_launch_itemManager(AuditManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'editing': record.editing,
