@@ -16,14 +16,14 @@ class Operation_levelQuerySet(BaseOperationQuerySet):
 
 class Operation_levelManager(AuditManager):
 
-    @staticmethod
-    def props():
+    @classmethod
+    def props(cls):
         return BitField(flags=(
             ('isProductionOrder', 'Уровень заказа на производство'),  # 1
         ), default=0, db_index=True)
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'editing': record.editing,
