@@ -18,7 +18,7 @@ class Operation_levelQuerySet(BaseOperationQuerySet):
 
 class Operation_level_viewManager(AuditManager):
 
-    def getRecord(record):
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'editing': record.editing,
