@@ -39,12 +39,12 @@ class Operation_locations_viewQuerySet(CommonQuerySet):
 
 class Operation_locations_viewManager(CommonManager):
 
-    @staticmethod
-    def getRecordLocations(record):
+    @classmethod
+    def getRecordLocations(cls, record):
         return dict(id=record.location.id, title=record.location.name, prompt=record.location.full_name)
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'code': record.code,
