@@ -15,8 +15,8 @@ class Operation_noteQuerySet(BaseOperationQuerySet):
 
 class Operation_noteManager(AuditManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'editing': record.editing,
