@@ -47,8 +47,8 @@ class Operation_operationQuerySet(BaseOperationQuerySet):
 
 class Operation_operationManager(AuditManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'editing': record.editing,
@@ -56,8 +56,8 @@ class Operation_operationManager(AuditManager):
         }
         return res
 
-    @staticmethod
-    def props():
+    @classmethod
+    def props(cls):
         return BitField(flags=(
             ('direct_created', 'Созданный после включения в производственную спецификацию'),  # 0-1
             ('updated', 'Обновленный'),  # 0-1
