@@ -18,8 +18,8 @@ class Operation_operation_historyQuerySet(AuditHistoryQuerySet):
 
 class Operation_operation_historyManager(AuditHistoryManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'code': record.code,
