@@ -62,19 +62,19 @@ class Operation_refsManager(TreeAuditModelManager):
         deleted = operation_refs.delete()
         logger.debug(f'\ndeleted: {deleted}')
 
-    @staticmethod
-    def props():
+    @classmethod
+    def props(cls):
         return BitField(flags=(
             ('inner_routing', 'Связь операций внутри товарной позиции'),  # 0-1
             ('outer_routing', 'Связь операций между товарными позициями'),  # 1-2
             ('product_order_routing', 'Связи в блоке задания на производство'),  # 2-4
             ('product_making', 'Связи выпуска'),  # 3-8
             ('product_making_block', 'Блок операций выпуска, удаляется как одно целое'),  # 4-16
-            ('for_grouped', 'Cгруппировано в задании на производство'),  # 5-32
+            ('maked_for_grouped', 'Создано как группирующая позиция, (избыточная)'),  # 5-32
         ), default=0, db_index=True)
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'parent': record.parent.id if record.parent else None,
