@@ -25,8 +25,8 @@ class Operation_typesQuerySet(BaseRefQuerySet):
 
 class Operation_typesManager(BaseRefManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         from kaf_pas.planing.models.status_operation_types import Status_operation_typesManager
         from kaf_pas.planing.models.status_operation_types import Status_operation_types
         res = {
