@@ -68,13 +68,13 @@ class OperationsQuerySet(BaseRefQuerySet, CommonManagetWithLookUpFieldsQuerySet,
 
 class OperationsManager(CommonManagetWithLookUpFieldsManager):
 
-    @staticmethod
-    def check_refs_free(operation_id):
+    @classmethod
+    def check_refs_free(cls, operation_id):
         from kaf_pas.planing.models.operation_refs import Operation_refs
         return Operation_refs.objects.filter(child_id=operation_id).count() == 0 and Operation_refs.objects.filter(parent_id=operation_id).count() == 0
 
-    @staticmethod
-    def delete_recursive(operation, user, soft_delete=False, opertypes=None, pre_delete_function=None, lock=True):
+    @classmethod
+    def delete_recursive(cls, operation, user, soft_delete=False, opertypes=None, pre_delete_function=None, lock=True):
         from kaf_pas.planing.models.operation_refs import Operation_refs
         key = f'OperationsManager.delete_recursive_{operation.id}'
         if lock:
@@ -144,8 +144,8 @@ class OperationsManager(CommonManagetWithLookUpFieldsManager):
         if lock:
             settings.LOCKS.release(key)
 
-    @staticmethod
-    def set_location(location_id, operation_id, resource_id=None):
+    @classmethod
+    def set_location(cls, location_id, operation_id, resource_id=None):
         from kaf_pas.production.models.resource import Resource
         from kaf_pas.planing.models.operation_resources import Operation_resources
         from clndr.models.calendars import CalendarsManager
@@ -165,8 +165,8 @@ class OperationsManager(CommonManagetWithLookUpFieldsManager):
 
             Operation_resources.objects.update_or_create(operation_id=operation_id, resource=resource)
 
-    @staticmethod
-    def set_anothers(operation_id, item_id=None, edizm_id=None, value=None, color_id=None, old_data=dict()):
+    @classmethod
+    def set_anothers(cls, operation_id, item_id=None, edizm_id=None, value=None, color_id=None, old_data=dict()):
         from kaf_pas.planing.models.operation_item import Operation_item
         from kaf_pas.planing.models.operation_value import Operation_value
         from kaf_pas.planing.models.operation_color import Operation_color
@@ -326,8 +326,8 @@ class OperationsManager(CommonManagetWithLookUpFieldsManager):
                         res += 1
         return res
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'num': record.num,
@@ -394,8 +394,6 @@ def pre_delete(sender, **kwargs):
 
     instance = kwargs.get('instance')
     if instance.opertype == settings.OPERS_TYPES_STACK.PRODUCTION_TASK:
-        # if flen(instance.minus_values) > 0:
-        #     raise Exception(f'Удаление невозможно, есть связанные выпуски.')
 
         Production_orderManager.delete_redundant_planing_production_order_table(instance)
         Production_orderManager.refresh_all(
