@@ -29,8 +29,8 @@ class Operations_viewQuerySet(TreeAuditModelQuerySet):
 
 class Operations_viewManager(TreeAuditModelManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'creator_id': record.creator.id,
             'date': record.date,
