@@ -59,8 +59,8 @@ class Production_order_opersQuerySet(CommonQuerySet):
 
 
 class Production_order_opersManager(CommonManager):
-    @staticmethod
-    def getRecord(record, user=None):
+    @classmethod
+    def getRecord(cls, record, user=None):
         from kaf_pas.production.models.operation_executor import Operation_executor
 
         if user is None:
@@ -76,65 +76,62 @@ class Production_order_opersManager(CommonManager):
                     enabled = record.resource.location.id in location_ids if record.resource else False
 
         res = {
-            # 'location_sector_id': record.location_sector.id,
+
             'creator__short_name': record.creator.get_short_name,
             'date': record.date,
-            'production_operation_is_absorption': record.production_operation_is_absorption,
-            'parent_id': record.parent_id,
             'description': record.description,
             'edizm__name': ' / '.join(record.edizm_arr) if record.edizm_arr is not None else None,
             'enabled': enabled,
             'id': record.id,
+            'isDeleted': record.isDeleted,
             'item_id': record.item.id,
             'launch_id': record.launch.id,
-            'location_id': record.location.id,
             'location__code': record.location.code,
             'location__full_name': record.location.full_name,
             'location__name': record.location.name,
-            'location_fin_id': record.location_fin.id if record.location_fin else None,
             'location_fin__code': record.location_fin.code if record.location_fin else None,
             'location_fin__full_name': record.location_fin.full_name if record.location_fin else None,
             'location_fin__name': record.location_fin.name if record.location_fin else None,
+            'location_fin_id': record.location_fin.id if record.location_fin else None,
+            'location_id': record.location.id,
             'num': record.id,
+            'parent_id': record.parent_id,
             'production_operation__full_name': record.operation_operation.production_operation.full_name if record.operation_operation else None,
             'production_operation__name': record.operation_operation.production_operation.name if record.operation_operation else None,
             'production_operation_attrs': record.production_operation_attrs,
+            'production_operation_color__color': record.production_operation_color.color if record.production_operation_color and record.production_operation_color else None,
+            'production_operation_color__name': record.production_operation_color.name if record.production_operation_color and record.production_operation_color else None,
+            'production_operation_color_id': record.production_operation_color.id if record.production_operation_color and record.production_operation_color else None,
             'production_operation_colors': record.production_operation_colors,
             'production_operation_edizm__name': record.operation_operation.ed_izm.name if record.operation_operation and record.operation_operation.ed_izm else None,
             'production_operation_edizm_id': record.operation_operation.ed_izm.id if record.operation_operation and record.operation_operation.ed_izm else None,
-
-            'production_operation_color_id': record.production_operation_color.id if record.production_operation_color and record.production_operation_color else None,
-            'production_operation_color__name': record.production_operation_color.name if record.production_operation_color and record.production_operation_color else None,
-            'production_operation_color__color': record.production_operation_color.color if record.production_operation_color and record.production_operation_color else None,
-
             'production_operation_id': record.operation_operation.production_operation.id if record.operation_operation else None,
+            'production_operation_is_absorption': record.production_operation_is_absorption,
+            'production_operation_is_grouped': record.production_operation_is_grouped,
+            'production_operation_is_launched': record.production_operation_is_launched,
+            'production_operation_is_transportation': record.production_operation_is_transportation,
             'production_operation_num': record.operation_operation.num if record.operation_operation else None,
             'production_operation_qty': record.operation_operation.qty if record.operation_operation else None,
             'resource__code': record.resource.code,
             'resource__description': record.resource.description,
             'resource__name': record.resource.name,
-            'resource_id': record.resource.id,
             'resource_fin__code': record.resource_fin.code if record.resource_fin is not None else None,
             'resource_fin__description': record.resource_fin.description if record.resource_fin is not None else None,
             'resource_fin__name': record.resource_fin.name if record.resource_fin is not None else None,
             'resource_fin_id': record.resource_fin.id if record.resource_fin is not None else None,
-            'value_sum': DecimalToStr(record.value_sum),
+            'resource_id': record.resource.id,
+            'value1_sum': DecimalToStr(record.value1_sum),
             'value_made': DecimalToStr(record.value_made),
             'value_odd': DecimalToStr(record.value_odd),
-            'value_ship': DecimalToStr(record.value_ship),
             'value_odd_ship': DecimalToStr(record.value_odd_ship),
-            'value1_sum': DecimalToStr(record.value1_sum),
-            # 'value1_sum_len': len(record.value1_sum),
+            'value_ship': DecimalToStr(record.value_ship),
             'value_start': DecimalToStr(record.value_start),
-            'isDeleted': record.isDeleted,
-            'production_operation_is_transportation': record.production_operation_is_transportation,
-            'production_operation_is_launched': record.production_operation_is_launched,
-            'production_operation_is_grouped': record.production_operation_is_grouped,
+            'value_sum': DecimalToStr(record.value_sum),
         }
         return DelProps(res)
 
-    @staticmethod
-    def refreshRows(ids, user):
+    @classmethod
+    def refreshRows(cls, ids, user):
         from kaf_pas.planing.models.production_order import Production_orderManager
 
         if ids is None:
@@ -144,8 +141,8 @@ class Production_order_opersManager(CommonManager):
         records = [Production_order_opersManager.getRecord(record, user) for record in Production_order_opers.objects.filter(id__in=ids)]
         WebSocket.row_refresh_grid(grid_id=settings.GRID_CONSTANTS.refresh_operationsGrid_row, records=records)
 
-    @staticmethod
-    def fullRows(suffix=''):
+    @classmethod
+    def fullRows(cls, suffix=''):
         WebSocket.full_refresh_grid(grid_id=f'{settings.GRID_CONSTANTS.refresh_operationsGrid}{suffix}')
 
     def createFromRequest(self, request):
@@ -248,8 +245,9 @@ class Production_order_opers(AuditModel):
 
     @property
     def right_neighbour(self):
-        if self.production_operation_num == len(self.all_childs):
+        if self.production_operation_num >= len(self.all_childs):
             return None
+
         return self.all_childs[self.production_operation_num]
 
     @property
