@@ -26,15 +26,15 @@ logger = logging.getLogger(__name__)
 
 
 class Production_order_opers_per_launchManager(CommonManager):
-    @staticmethod
-    def refreshRows(ids):
+    @classmethod
+    def refreshRows(cls,ids):
         if isinstance(ids, int):
             ids = [ids]
         records = [Production_order_opersManager.getRecord(record) for record in Production_order_opers_per_launch.objects.filter(id__in=ids)]
         WebSocket.row_refresh_grid(grid_id=settings.GRID_CONSTANTS.refresh_operationsGrid_row, records=records)
 
-    @staticmethod
-    def fullRows(suffix=''):
+    @classmethod
+    def fullRows(cls, suffix=''):
         WebSocket.full_refresh_grid(grid_id=f'{settings.GRID_CONSTANTS.refresh_operationsGrid}{suffix}')
 
     def get_queryset(self):
@@ -83,6 +83,7 @@ class Production_order_opers_per_launch(AuditModel):
     props = Operation_refsManager.props()
 
     objects = Production_order_opers_per_launchManager()
+    tree_objects = TreeAuditModelManager()
 
     def __str__(self):
         return f'ID: {self.id}, production_operation: [{self.production_operation}]'
