@@ -48,15 +48,15 @@ class Production_order_valuesQuerySet(OperationsQuerySet):
 
 
 class Production_order_valuesManager(OperationsManager):
-    @staticmethod
-    def refreshRows(ids):
+    @classmethod
+    def refreshRows(cls,ids):
         if isinstance(ids, int):
             ids = [ids]
         records = [Production_order_valuesManager.getRecord(record) for record in Production_order_values.objects.filter(id__in=ids)]
         WebSocket.row_refresh_grid(grid_id=settings.GRID_CONSTANTS.refresh_production_order_operationsValues_grid_row, records=records)
 
-    @staticmethod
-    def fullRows(suffix=''):
+    @classmethod
+    def fullRows(cls, suffix=''):
         WebSocket.full_refresh_grid(grid_id=f'{settings.GRID_CONSTANTS.refresh_production_order_operationsValues_grid}{suffix}')
 
     def createFromRequest(self, request, removed=None):
@@ -90,7 +90,7 @@ class Production_order_valuesManager(OperationsManager):
             except Exception as ex:
                 raise ex
 
-        Production_orderManager.update_redundant_planing_production_order_table(ids=production_order)
+        # Production_orderManager.update_redundant_planing_production_order_table(ids=production_order)
         Production_orderManager.refresh_all(
             buffer_refresh=True,
             ids=production_order,
@@ -153,8 +153,8 @@ class Production_order_valuesManager(OperationsManager):
 
         return res
 
-    @staticmethod
-    def getRecord(record, enable):
+    @classmethod
+    def getRecord(cls, record, enable):
 
         if enable == False:
             if record.opertype.is_minus:
@@ -165,27 +165,23 @@ class Production_order_valuesManager(OperationsManager):
                 enable = True
 
         res = {
-            'id': record.id,
             'color__color': record.color.color if record.color else None,
             'color__name': record.color.name if record.color else None,
             'color_id': record.color.id if record.color else None,
-
-            'launch__code': record.launch.code if record.launch else None,
-            'launch__date': record.launch.date if record.launch else None,
-            'launch_id': record.launch.id if record.launch else None,
-
-            'demand__code': record.demand.code if record.demand else None,
-            'demand__date': record.demand.date if record.demand else None,
-            'demand_id': record.demand.id if record.demand else None,
-
             'creator__short_name': record.creator.get_short_name,
             'creator_id': record.creator.id,
             'date': record.date,
+            'demand__code': record.demand.code if record.demand else None,
+            'demand__date': record.demand.date if record.demand else None,
+            'demand_id': record.demand.id if record.demand else None,
             'edizm__name': record.edizm.name,
             'edizm_id': record.edizm.id,
             'enabled': enable,
+            'id': record.id,
+            'launch__code': record.launch.code if record.launch else None,
+            'launch__date': record.launch.date if record.launch else None,
+            'launch_id': record.launch.id if record.launch else None,
             'value': DecimalToStr(record.value) if not record.opertype.is_minus else None,
-            # 'value_minus': blinkString(text=DecimalToStr(-record.value), blink=False, color=red) if record.opertype.is_minus else None,
             'value_minus': DecimalToStr(-record.value) if record.opertype.is_minus else None,
         }
         return DelProps(res)
