@@ -200,8 +200,8 @@ class RoutingQuerySet(Operations_viewQuerySet):
 class RoutingManager(Operations_viewManager):
     routing_ext = Routing_ext()
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         return Operations_rout_viewManager.getRecord(record)
 
     def get_queryset(self):
