@@ -12,8 +12,8 @@ class SectionsQuerySet(BaseRefQuerySet):
 
 class SectionsManager(BaseRefManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'code': record.code,
