@@ -41,12 +41,13 @@ class Status_operation_typesManager(BaseRefManager):
         props = TurnBitOn(props, 1) if blink else TurnBitOff(props, 1)
         setAttr(_data, 'props', props)
 
+        _data=self.delete_underscore_element(_data)
         super().filter(id=_data.get('id')).update(**_data)
         setAttr(data, 'props', props)
         return data
 
-    @staticmethod
-    def make_statuses(opertype, status_map):
+    @classmethod
+    def make_statuses(cls, opertype, status_map):
         res = dict()
         key = 'Status_operation_typesManager.make_statuses'
         settings.LOCKS.acquire(key)
@@ -66,8 +67,8 @@ class Status_operation_typesManager(BaseRefManager):
         settings.LOCKS.release(key)
         return res
 
-    @staticmethod
-    def get_status(opertype_id, code):
+    @classmethod
+    def get_status(cls, opertype_id, code):
         key = f'Status_operation_typesManager.make_statuses:{opertype_id}.{code}'
         settings.LOCKS.acquire(key)
         res, _ = Status_operation_types.objects.get_or_create(
@@ -77,8 +78,8 @@ class Status_operation_typesManager(BaseRefManager):
         settings.LOCKS.release(key)
         return res
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'code': record.code,
