@@ -14,8 +14,8 @@ class Tmp_operation_infoQuerySet(AuditQuerySet):
 
 class Tmp_operation_infoManager(AuditManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'code': record.code,
