@@ -73,8 +73,8 @@ class TMPOWrapper(Wrapper):
 
 class Tmp_operation_valueManager(AuditManager):
 
-    @staticmethod
-    def props():
+    @classmethod
+    def props(cls):
         return BitField(flags=(
             ('enabled', 'Доступно'),  # 1
         ), db_index=True, default=1)
@@ -148,8 +148,8 @@ class Tmp_operation_valueManager(AuditManager):
                 # res = Tmp_operation_value_viewManager.getRecord(updated_row)
             return _data
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'parent': record.parent.id if record.parent else None,
