@@ -94,20 +94,20 @@ class TMOV_Wrapper(Wrapper):
 
 class Tmp_operation_value_viewManager(AuditManager):
 
-    @staticmethod
-    def fullRows(suffix=''):
+    @classmethod
+    def fullRows(cls, suffix=''):
         WebSocket.full_refresh_grid(grid_id=f'{settings.GRID_CONSTANTS.tmp_operation_value_view_grid}{suffix}')
 
-    @staticmethod
-    def refreshRows(ids):
+    @classmethod
+    def refreshRows(cls,ids):
         if isinstance(ids, int):
             ids = [ids]
 
         records = [Tmp_operation_value_viewManager.getRecord(record) for record in Tmp_operation_value_view.objects.filter(id__in=ids)]
         WebSocket.row_refresh_grid(grid_id=settings.GRID_CONSTANTS.tmp_operation_value_view_grid_row, records=records)
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         from kaf_pas.ckk.models.item_line import Item_lineManager
         value_odd = record.value_odd
         if value_odd is not None and record.enabled == True:
@@ -175,7 +175,7 @@ class Tmp_operation_value_view(AuditModel):
     last_tech_operation = ForeignKeyCascade(Operations)
     value_sum = DecimalField(verbose_name="Количество по документации", decimal_places=4, max_digits=19)
     value_odd = DecimalField(verbose_name="Количество Остаток", decimal_places=4, max_digits=19, null=True, blank=True)
-    value1_sum = DecimalField(verbose_name="Количество на еденицу продукции", decimal_places=4, max_digits=19)
+    value1_sum = DecimalField(verbose_name="Количество на единицу продукции", decimal_places=4, max_digits=19)
     section = CodeField(null=True, blank=True)
     isFolder = BooleanField()
     enabled = BooleanField()
