@@ -2,6 +2,8 @@ import logging
 
 from django.db import ProgrammingError
 
+from isc_common.common import unknown, name_unknown, name_started_another, started_another, gray, light_green, black
+
 logger = logging.getLogger(__name__)
 
 ACOUNTING = 'ACOUNTING'
@@ -13,6 +15,8 @@ DETAIL_OPERS_PRD_TSK = 'DETAIL_OPERS_PRD_TSK'
 DETAIL_SUM_PRD_TSK = 'DETAIL_SUM_PRD_TSK'
 LAUNCH_TSK = 'LAUNCH_TSK'
 MADE_OPRS_MNS_TSK = 'MADE_OPRS_MNS_TSK'
+MADE_OPRS_RESERV_PLS_TSK = 'MADE_OPRS_RESERV_PLS_TSK'
+MADE_OPRS_RESERV_MNS_TSK = 'MADE_OPRS_RESERV_MNS_TSK'
 MADE_OPRS_PLS_TSK = 'MADE_OPRS_PLS_TSK'
 MADE_OPRS_PLS_GRP_TSK = 'MADE_OPRS_PLS_GRP_TSK'
 PRD_TSK = 'PRD_TSK'
@@ -49,11 +53,13 @@ class Operation_typesStack:
                         dict(code=new, name=name_new_s, color=blue),
                         dict(code=new_man, name=name_new_h, color=blue),
                         dict(code=started, name=name_started, color=green),
-                        dict(code=restarted, name=name_restarted, color=green),
+                        dict(code=restarted, name=name_restarted, color=light_green),
+                        dict(code=started_another, name=name_started_another, color=gray),
                         dict(code=transferred, name=name_transferred),
                         dict(code=stoped, name=name_stoped, color='#310062'),
-                        dict(code=doing, name=name_doing),
-                        dict(code=closed, name=name_closed),
+                        dict(code=doing, name=name_doing, color="#333399"),
+                        dict(code=closed, name=name_closed, color=black),
+                        dict(code=unknown, name=name_unknown),
                     ]
                 )
 
@@ -163,7 +169,35 @@ class Operation_typesStack:
                     ]
                 )
 
+                self.MADE_OPERATIONS_RESERV_PLUS_TASK, _ = Operation_types.objects.update_or_create(code=MADE_OPRS_RESERV_PLS_TSK, defaults=dict(
+                    props=Operation_types.props.plus,
+                    name='Выполнение резервирующей производственной операции (прибавляющая)',
+                    editing=False,
+                    deliting=False,
+                    parent=self.PRODUCTION_TASK
+                ))
 
+                self.MADE_OPERATIONS_RESERV_PLUS_STATUSES = Status_operation_typesManager.make_statuses(
+                    opertype=self.MADE_OPERATIONS_RESERV_PLUS_TASK,
+                    status_map=[
+                        dict(code=new, name=name_new),
+                    ]
+                )
+
+                self.MADE_OPERATIONS_RESERV_MINUS_TASK, _ = Operation_types.objects.update_or_create(code=MADE_OPRS_RESERV_MNS_TSK, defaults=dict(
+                    props=Operation_types.props.minus | Operation_types.props.accounting,
+                    name='Выполнение резервирующей производственной операции (вычитающая)',
+                    editing=False,
+                    deliting=False,
+                    parent=self.PRODUCTION_TASK
+                ))
+
+                self.MADE_OPERATIONS_RESERV_MINUS_STATUSES = Status_operation_typesManager.make_statuses(
+                    opertype=self.MADE_OPERATIONS_RESERV_MINUS_TASK,
+                    status_map=[
+                        dict(code=new, name=name_new),
+                    ]
+                )
 
                 self.CALC_TASKS, _ = Operation_types.objects.update_or_create(code=CLC_TSK, defaults=dict(
                     props=0,
