@@ -13,13 +13,17 @@ urlpatterns = [
     path('Production_order/Add', production_order.Production_order_Add),
     path('Production_order/Update', production_order.Production_order_Update),
     path('Production_order/Grouping', production_order.Production_order_Grouping),
+    path('Production_order/UnGrouping', production_order.Production_order_UnGrouping),
     path('Production_order/UpdateForwarding', production_order.Production_order_UpdateForwarding),
     path('Production_order/Remove', production_order.Production_order_Remove),
     path('Production_order/Lookup/', production_order.Production_order_Lookup),
     path('Production_order/Info/', production_order.Production_order_Info),
     path('Production_order/Copy', production_order.Production_order_Copy),
     path('Production_order/SetStartStatus', production_order.Production_order_SetStartStatus),
+    path('Production_order/SetMadedStatus', production_order.Production_order_SetMadedStatus),
     path('Production_order/SetFinishStatus', production_order.Production_order_SetFinishStatus),
+    path('Production_order/SetFinishStatus_Lookup/', production_order.Production_order_SetFinishStatus_Lookup),
+    path('Production_order/FinishFormType/', production_order.Production_order_SetFinishFormType),
     path('Production_order/getValue_made/', production_order.Production_order_getValue_made),
     path('Production_order/MakeProdOrder', production_order.Production_order_MakeProdOrder),
     path('Production_order/DeleteProdOrder', production_order.Production_order_DeleteProdOrder),
