@@ -1,7 +1,7 @@
 from django.conf import settings
 from django.db import connection
 
-from isc_common import dictinct_list
+from isc_common import dictinct_list, setAttr
 from isc_common.common.mat_views import refresh_mat_view
 from isc_common.http.DSRequest import DSRequest
 from isc_common.http.DSResponse import DSResponseUpdate, DSResponseAdd, DSResponse, JsonResponseWithException, JsonWSResponseWithException
@@ -23,11 +23,18 @@ def Production_order_Fetch(request):
     criteria = _request.get_criteria()
 
     arranged_lst = list(filter(lambda x: x.get('fieldName') == 'arranged', criteria))
+    arranges_exucutors_lst = list(filter(lambda x: x.get('fieldName') == 'arranges_exucutors', criteria))
+
     if len(arranged_lst) > 0:
         arranged = arranged_lst[0].get('value')
     else:
         arranged = False
 
+    arranges_exucutors = None
+    if arranged is False and len(arranges_exucutors_lst) > 0:
+        arranged = True
+        arranges_exucutors = arranges_exucutors_lst[0].get('value')
+
     location_id_lst = list(filter(lambda x: x.get('fieldName') == 'location_id', criteria))
     if len(location_id_lst) > 0:
         location_id = location_id_lst[0].get('value')
@@ -192,10 +199,29 @@ def Production_order_per_launch_Fetch(request):
                     status=RPCResponseConstant.statusSuccess).response)
 
 
+def get_qty_production_orders(launch, location_id, opers_types, request):
+    if launch is None:
+        if request.is_admin or request.is_develop:
+            return Production_order.objects.filter(opertype__in=opers_types).filter(location_ids__overlap=[location_id]).count()
+        else:
+            return Production_order.objects.filter(opertype__in=opers_types).filter(location_ids__overlap=[location_id]).filter(exucutors__overlap=[request.user_id]).count()
+    elif launch.parent is None:
+        if request.is_admin or request.is_develop:
+            return Production_order.objects.filter(opertype__in=opers_types, launch=launch).filter(location_ids__overlap=[location_id]).count()
+        else:
+            return Production_order.objects.filter(opertype__in=opers_types, launch=launch).filter(location_ids__overlap=[location_id]).filter(exucutors__overlap=[request.user_id]).count()
+    else:
+        if request.is_admin or request.is_develop:
+            return Production_order_per_launch.objects.filter(opertype__in=opers_types, launch=launch).filter(location_ids__overlap=[location_id]).count()
+        else:
+            return Production_order_per_launch.objects.filter(opertype__in=opers_types, launch=launch).filter(location_ids__overlap=[location_id]).filter(exucutors__overlap=[request.user_id]).count()
+
+
 @JsonResponseWithException()
 def Production_order_FetchLocations(request):
     from kaf_pas.production.models.launches import Launches
     from kaf_pas.planing.models.operation_item_view import Operation_item_view
+    from kaf_pas.ckk.models.locations_view import Locations_view
 
     opers_types = (
         settings.OPERS_TYPES_STACK.PRODUCTION_TASK.id,
@@ -206,6 +232,15 @@ def Production_order_FetchLocations(request):
     launch = None
 
     data = _request.get_data()
+    location = data.get('location')
+    if location is None:
+        location = data.get('location_id')
+
+    if location is not None and isinstance(location, list):
+        locationw = list(map(lambda x: x.workshop.id, Locations_view.objects.filter(id__in=location)))
+        location = list(set(location).union(set(locationw)))
+        setAttr(data, 'location', location)
+
     launch_id = data.get('launch_id')
     if launch_id is not None:
         launch = Launches.objects.get(id=launch_id)
@@ -219,72 +254,59 @@ def Production_order_FetchLocations(request):
             item_ids = tuple([0])
 
     if _request.is_admin or _request.is_develop:
-        if item_ids is not None:
+        if isinstance(item_ids, list):
             if launch.parent is not None:
-                sql_str = f'''select s.location_id,
-                               get_full_name(s.location_id, 'ckk_locations') location_full_name,
-                               cl.name as                                    location_name,
-                               cl.level_grouping 
-                        from (
-                                 select distinct get_workshop_id(s.location_id_in1, 'ckk_locations') location_id
-                                 from (
-                                          SELECT distinct choprs.location_id location_id_in1
-                                          FROM planing_operation_resources as pors
-                                          join planing_operation_launches as polch on polch.operation_id = pors.operation_id
-                                          join production_resource as choprs on pors.resource_id = choprs.id
-                                          join planing_operations as po on polch.operation_id = po.id
-                                          join planing_operation_refs as porf on po.id = porf.child_id
-                                          join planing_operation_item as poit on poit.operation_id = pors.operation_id
-                                          WHERE po.opertype_id in %s
-                                            AND porf.props in %s
-                                            AND poit.item_id in %s
-                                            AND polch.launch_id = %s
-                                      ) as s) as s
-                                 join ckk_locations cl on s.location_id = cl.id
-                        order by cl.name'''
+                sql_str = f'''SELECT distinct choplw.id       as location_id,
+                                                choplw.name     as location_name,
+                                                choplw.name as location_full_name
+                                FROM planing_operation_resources as pors
+                                         join planing_operation_launches as polch on polch.operation_id = pors.operation_id
+                                         join production_resource as choprs on pors.resource_id = choprs.id
+                                         join ckk_locations as chopcl on chopcl.id = choprs.location_id
+                                         join ckk_locations as choplw on choplw.id = chopcl.workshop_id
+                                         join planing_operations as po on polch.operation_id = po.id
+                                         join planing_operation_refs as porf on po.id = porf.child_id
+                                         join planing_operation_item as poit on poit.operation_id = pors.operation_id
+                                WHERE po.opertype_id in %s
+                                  AND porf.props in %s
+                                  AND poit.item_id in %s
+                                  AND polch.launch_id = %s
+                                order by choplw.name'''
             else:
-                sql_str = f'''select s.location_id,
-                                              get_full_name(s.location_id, 'ckk_locations') location_full_name,
-                                              cl.name as                                    location_name,
-                                              cl.level_grouping  
-                                       from (
-                                                select distinct get_workshop_id(s.location_id_in1, 'ckk_locations') location_id
-                                                from (
-                                                         SELECT distinct choprs.location_id location_id_in1
-                                                         FROM planing_operation_resources as pors
-                                                         join production_resource as choprs on pors.resource_id = choprs.id
-                                                         join planing_operations as po on pors.operation_id = po.id
-                                                         join planing_operation_refs as porf on po.id = porf.child_id
-                                                         join planing_operation_item as poit on poit.operation_id = pors.operation_id
-                                                         WHERE po.opertype_id in %s
-                                                           AND porf.props in %s
-                                                           AND poit.item_id in %s
-                                                     ) as s) as s
-                                                join ckk_locations cl on s.location_id = cl.id
-                                       order by cl.name'''
+                sql_str = f'''SELECT distinct choplw.id       as location_id,
+                                                choplw.name     as location_name,
+                                                choplw.name as location_full_name
+                                FROM planing_operation_resources as pors
+                                         join planing_operation_launches as polch on polch.operation_id = pors.operation_id
+                                         join production_resource as choprs on pors.resource_id = choprs.id
+                                         join ckk_locations as chopcl on chopcl.id = choprs.location_id
+                                         join ckk_locations as choplw on choplw.id = chopcl.workshop_id
+                                         join planing_operations as po on polch.operation_id = po.id
+                                         join planing_operation_refs as porf on po.id = porf.child_id
+                                         join planing_operation_item as poit on poit.operation_id = pors.operation_id
+                                WHERE po.opertype_id in %s
+                                  AND porf.props in %s
+                                  AND poit.item_id in %s
+                                order by choplw.name'''
 
         else:
-            sql_str = f'''select s.location_id,
-                               get_full_name(s.location_id, 'ckk_locations') location_full_name,
-                               cl.name as                                    location_name,
-                               cl.level_grouping 
-                        from (
-                                 select distinct get_workshop_id(s.location_id_in1, 'ckk_locations') location_id
-                                 from (
-                                          SELECT distinct choprs.location_id location_id_in1
-                                          FROM planing_operation_resources as pors
-                                                   join production_resource as choprs on pors.resource_id = choprs.id
-                                                   join planing_operations as po on pors.operation_id = po.id
-                                                   join planing_operation_refs as porf on po.id = porf.child_id
-                                          WHERE po.opertype_id in %s
-                                            AND porf.props in %s
-                                      ) as s) as s
-                                 join ckk_locations cl on s.location_id = cl.id
-                                 order by cl.name'''
+            sql_str = f'''SELECT distinct choplw.id   as location_id,
+                                            choplw.name as location_name,
+                                            choplw.name as location_full_name
+                            FROM planing_operation_resources as pors
+                                     join planing_operation_launches as polch on polch.operation_id = pors.operation_id
+                                     join production_resource as choprs on pors.resource_id = choprs.id
+                                     join ckk_locations as chopcl on chopcl.id = choprs.location_id
+                                     join ckk_locations as choplw on choplw.id = chopcl.workshop_id
+                                     join planing_operations as po on polch.operation_id = po.id
+                                     join planing_operation_refs as porf on po.id = porf.child_id
+                            WHERE po.opertype_id in %s
+                            AND porf.props in %s
+                            order by choplw.name'''
 
         with connection.cursor() as cursor:
             res = []
-            if item_ids is not None:
+            if isinstance(item_ids, list):
                 if launch.parent is not None:
                     cursor.execute(sql_str, [opers_types, (Production_order.props.product_order_routing,), item_ids, launch.parent.id])
                 else:
@@ -293,8 +315,10 @@ def Production_order_FetchLocations(request):
                 cursor.execute(sql_str, [opers_types, (Production_order.props.product_order_routing,)])
             rows = cursor.fetchall()
             for row in rows:
-                id, prompt, title, level_grouping = row
-                res.append(dict(id=id, title=title, prompt=prompt, level_grouping=level_grouping))
+                id, prompt, title = row
+
+                if get_qty_production_orders(launch=launch, location_id=id, opers_types=opers_types, request=_request) > 0:
+                    res.append(dict(id=id, title=title, prompt=prompt))
 
         return JsonResponse(
             DSResponse(
@@ -310,53 +334,41 @@ def Production_order_FetchLocations(request):
             location = tuple(0)
 
         if item_ids is not None:
-            sql_str = f'''select s.location_id,
-                           get_full_name(s.location_id, 'ckk_locations') location_full_name,
-                           cl.name as                                    location_name,
-                           cl.level_grouping 
-                        from (
-                                 select distinct get_workshop_id(s.location_id_in1, 'ckk_locations') location_id
-                                 from (
-                                          SELECT distinct choprs.location_id location_id_in1
-                                          FROM planing_operation_resources as pors
-                                          join planing_operation_launches as polch on polch.operation_id = pors.operation_id
-                                          join production_resource as choprs on pors.resource_id = choprs.id
-                                          join planing_operations as po on polch.operation_id = po.id
-                                          join planing_operation_executor as poex on poex.operation_id = po.id
-                                          join planing_operation_refs as porf on po.id = porf.child_id
-                                          join planing_operation_item as poit on poit.operation_id = pors.operation_id
-                                          WHERE po.opertype_id in %s
-                                            AND porf.props in %s
-                                            AND poit.item_id in %s
-                                            AND polch.launch_id = %s
-                                            AND poex.executor_id in %s
-                                      ) as s) as s
-                                 join ckk_locations cl on s.location_id = cl.id
-                        where s.location_id in %s    
-                        order by cl.name'''
+            sql_str = f'''SELECT distinct choplw.id       as location_id,
+                                            choplw.name     as location_name,
+                                            choplw.name as location_full_name
+                            FROM planing_operation_resources as pors
+                                     join planing_operation_launches as polch on polch.operation_id = pors.operation_id
+                                     join production_resource as choprs on choprs.location_id = choprs.id
+                                     join ckk_locations as choplc on choprs.location_id = choplc.id
+                                     join ckk_locations as choplw on choplw.id = choplc.workshop_id
+                                     join planing_operations as po on polch.operation_id = po.id
+                                     join planing_operation_executor as poex on poex.operation_id = po.id
+                                     join planing_operation_refs as porf on po.id = porf.child_id
+                                     join planing_operation_item as poit on poit.operation_id = pors.operation_id
+                            WHERE po.opertype_id in %s
+                              AND porf.props in %s
+                              AND poit.item_id in %s
+                              AND polch.launch_id = %s
+                              AND poex.executor_id in %s 
+                              and choplw.id in %s
+                            order by choplw.name'''
         else:
-            sql_str = f'''select s.*
-                            from (
-                                     select s.location_id,
-                                            get_full_name(s.location_id, 'ckk_locations') location_full_name,
-                                            cl.name as                                    location_name,
-                                            cl.level_grouping
-                                     from (
-                                              select distinct get_workshop_id(s.location_id_in1, 'ckk_locations') location_id
-                                              from (
-                                                       SELECT distinct choprs.location_id location_id_in1
-                                                       FROM planing_operation_resources as pors
-                                                                join production_resource as choprs on pors.resource_id = choprs.id
-                                                                join planing_operations as po on pors.operation_id = po.id
-                                                                join planing_operation_refs as porf on po.id = porf.child_id
-                                                                join planing_operation_executor as poex on poex.operation_id = po.id
-                                                       WHERE po.opertype_id in %s
-                                                         AND porf.props in %s
-                                                         AND poex.executor_id in %s
-                                                   ) as s) as s
-                                              join ckk_locations cl on s.location_id = cl.id
-                                     order by cl.name) as s
-                            where s.location_id in %s'''
+            sql_str = f'''SELECT distinct choplw.id       as location_id,
+                                            choplw.name     as location_name,
+                                            choplw.name as location_full_name
+                            FROM planing_operation_resources as pors
+                                     join production_resource as choprs on pors.resource_id = choprs.id
+                                     join ckk_locations as choplc on choprs.location_id = choplc.id
+                                     join ckk_locations as choplw on choplw.id = choplc.workshop_id
+                                     join planing_operations as po on pors.operation_id = po.id
+                                     join planing_operation_refs as porf on po.id = porf.child_id
+                                     join planing_operation_executor as poex on poex.operation_id = po.id
+                            WHERE po.opertype_id in  %s
+                              AND porf.props in  %s
+                              AND poex.executor_id in  %s
+                              and choplw.id in  %s
+                              order by choplw.name'''
 
         with connection.cursor() as cursor:
             res = []
@@ -366,8 +378,9 @@ def Production_order_FetchLocations(request):
                 cursor.execute(sql_str, [opers_types, (Production_order.props.product_order_routing,), (_request.user_id,), location])
             rows = cursor.fetchall()
             for row in rows:
-                id, prompt, title, level_grouping = row
-                res.append(dict(id=id, title=title, prompt=prompt, level_grouping=level_grouping))
+                id, prompt, title = row
+                if get_qty_production_orders(launch=launch, location_id=id, opers_types=opers_types, request=_request) > 0:
+                    res.append(dict(id=id, title=title, prompt=prompt))
 
         return JsonResponse(
             DSResponse(
@@ -449,11 +462,17 @@ def Production_order_Add(request):
 def Production_order_Update(request):
     return JsonResponse(DSResponseUpdate(data=Production_order.objects.updateFromRequest(request), status=RPCResponseConstant.statusSuccess).response)
 
+
 @JsonResponseWithException()
 def Production_order_Grouping(request):
     return JsonResponse(DSResponseUpdate(data=Production_order.objects.groupingFromRequest(request), status=RPCResponseConstant.statusSuccess).response)
 
 
+@JsonResponseWithException()
+def Production_order_UnGrouping(request):
+    return JsonResponse(DSResponseUpdate(data=Production_order.objects.unGroupingFromRequest(request), status=RPCResponseConstant.statusSuccess).response)
+
+
 @JsonWSResponseWithException()
 def Production_order_UpdateForwarding(request):
     return JsonResponse(DSResponseUpdate(data=Production_order.objects.updateFromRequestUpdateForwarding(request), status=RPCResponseConstant.statusSuccess).response)
@@ -469,6 +488,11 @@ def Production_order_Lookup(request):
     return JsonResponse(DSResponse(request=request, data=Production_order.objects.lookupFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)
 
 
+@JsonResponseWithException()
+def Production_order_SetFinishStatus_Lookup(request):
+    return JsonResponse(DSResponse(request=request, data=Production_order.objects.lookupFinishStatusFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)
+
+
 @JsonResponseWithException()
 def Production_order_Info(request):
     return JsonResponse(DSResponse(request=request, data=Production_order.objects.get_queryset().get_info(request=request), status=RPCResponseConstant.statusSuccess).response)
@@ -476,13 +500,24 @@ def Production_order_Info(request):
 
 @JsonResponseWithException()
 def Production_order_SetStartStatus(request):
-    return JsonResponse(DSResponse(request=request, data=Production_order.objects.get_queryset().get_setStartStatus(request=request), status=RPCResponseConstant.statusSuccess).response)\
+    return JsonResponse(DSResponse(request=request, data=Production_order.objects.get_queryset().get_setStartStatus(request=request), status=RPCResponseConstant.statusSuccess).response)
+
+
+@JsonResponseWithException()
+def Production_order_SetMadedStatus(request):
+    return JsonResponse(DSResponse(request=request, data=Production_order.objects.get_queryset().get_setMadedStatus(request=request), status=RPCResponseConstant.statusSuccess).response)
+
 
 @JsonResponseWithException()
 def Production_order_SetFinishStatus(request):
     return JsonResponse(DSResponse(request=request, data=Production_order.objects.get_queryset().get_setFinishStatus(request=request), status=RPCResponseConstant.statusSuccess).response)
 
 
+@JsonResponseWithException()
+def Production_order_SetFinishFormType(request):
+    return JsonResponse(DSResponse(request=request, data=Production_order.objects.get_queryset().get_FinishFormType(request=request), status=RPCResponseConstant.statusSuccess).response)
+
+
 @JsonResponseWithException()
 def Production_order_getValue_made(request):
     return JsonResponse(DSResponse(request=request, data=Production_order.objects.get_queryset().getValue_made(request=request), status=RPCResponseConstant.statusSuccess).response)
