@@ -7,21 +7,35 @@ from isc_common.http.response import JsonResponse
 from kaf_pas.planing.models.production_order_opers import Production_order_opers, Production_order_opersManager
 from kaf_pas.planing.models.production_order_opers_per_launch import Production_order_opers_per_launch
 
+production_order_opers_opers_types = [
+    settings.OPERS_TYPES_STACK.PRODUCTION_DETAIL_OPERS_TASK.id,
+]
+
 
 @JsonResponseWithException()
 def Production_order_opers_Fetch(request):
-    opers_types = [
-        settings.OPERS_TYPES_STACK.PRODUCTION_DETAIL_OPERS_TASK.id,
-    ]
-
     _request = DSRequest(request=request)
     return JsonResponse(
         DSResponse(
             request=request,
             data=Production_order_opers.objects.
+                select_related(
+                'creator',
+                'item',
+                'launch',
+                'location',
+                'location_fin',
+                'operation_operation',
+                'production_operation_color',
+                'production_operation_edizm',
+                'resource',
+                'resource_fin',
+                'status'
+            ).
                 filter(
-                opertype__in=opers_types,
-            ).distinct().
+                opertype__in=production_order_opers_opers_types,
+            ).
+                # distinct().
                 get_range_rows1(
                 request=request,
                 function=Production_order_opersManager.getRecord
@@ -31,18 +45,28 @@ def Production_order_opers_Fetch(request):
 
 @JsonResponseWithException()
 def Production_order_per_launch_FetchDetail(request):
-    opers_types = [
-        settings.OPERS_TYPES_STACK.PRODUCTION_DETAIL_OPERS_TASK.id,
-    ]
-
     # _request = DSRequest(request=request)
     return JsonResponse(
         DSResponse(
             request=request,
             data=Production_order_opers_per_launch.objects.
+                select_related(
+                'creator',
+                'item',
+                'launch',
+                'location',
+                'location_fin',
+                'operation_operation',
+                'production_operation_color',
+                'production_operation_edizm',
+                'resource',
+                'resource_fin',
+                'status'
+            ).
                 filter(
-                opertype__in=opers_types,
-            ).distinct().
+                opertype__in=production_order_opers_opers_types,
+            ).
+                # distinct().
                 get_range_rows1(
                 request=request,
                 function=Production_order_opersManager.getRecord
