@@ -1,3 +1,4 @@
+from isc_common.http.DSRequest import DSRequest
 from isc_common.http.DSResponse import DSResponseUpdate, DSResponseAdd, DSResponse, JsonResponseWithException
 from isc_common.http.RPCResponse import RPCResponseConstant
 from isc_common.http.response import JsonResponse
@@ -6,18 +7,30 @@ from kaf_pas.planing.models.production_order_values import Production_order_valu
 
 @JsonResponseWithException()
 def Production_order_values_Fetch(request):
-    # _request = DSRequest(request=request)
-
-    return JsonResponse(
-        DSResponse(
-            request=request,
-            data=Production_order_values.objects.
-                filter().
-                get_range_rows1(
+    _request = DSRequest(request=request)
+    if _request.user.is_admin or _request.user.is_develop:
+        return JsonResponse(
+            DSResponse(
                 request=request,
-                function=Production_order_valuesManager.getRecord
-            ),
-            status=RPCResponseConstant.statusSuccess).response)
+                data=Production_order_values.objects.
+                    filter().
+                    get_range_rows1(
+                    request=request,
+                    function=Production_order_valuesManager.getRecord
+                ),
+                status=RPCResponseConstant.statusSuccess).response)
+    else:
+        from kaf_pas.planing.models.operation_types import Operation_types
+        return JsonResponse(
+            DSResponse(
+                request=request,
+                data=Production_order_values.objects.
+                    exclude(opertype__props=Operation_types.props.minus).
+                    get_range_rows1(
+                    request=request,
+                    function=Production_order_valuesManager.getRecord
+                ),
+                status=RPCResponseConstant.statusSuccess).response)
 
 
 @JsonResponseWithException()
