@@ -64,4 +64,4 @@ class Command(BaseCommand):
                 pbar.update()
             pbar.close()
         percents = round(no * 100 / total, 2)
-        print(f'{no} - {percents}% Done.')
+        # print(f'{no} - {percents}% Done.')
