@@ -9,7 +9,7 @@ from isc_common.bit import IsBitOn
 from isc_common.fields.code_field import CodeStrictField
 from isc_common.fields.description_field import DescriptionField
 from isc_common.fields.name_field import NameField
-from isc_common.fields.related import ForeignKeyProtect
+from isc_common.fields.related import ForeignKeyProtect, ForeignKeySetNull
 from isc_common.http.DSRequest import DSRequest
 from isc_common.models.audit import AuditModel, AuditQuerySet
 from isc_common.models.tree_audit import TreeAuditModelManager
@@ -27,8 +27,8 @@ class Launch_item_lineQuerySet(AuditQuerySet):
 
 
 class Launch_item_lineManager(TreeAuditModelManager):
-    @staticmethod
-    def props():
+    @classmethod
+    def props(cls):
         return BitField(flags=(
             ('used', 'Доступность в данной производственной спецификации'),  # 1
         ), default=1, db_index=True)
@@ -71,6 +71,7 @@ class Launch_item_lineManager(TreeAuditModelManager):
         delAttr(data, 'edizm__name')
         delAttr(data, 'edizm__name')
         delAttr(data, 'enabled')
+        delAttr(data, 'qty_doc')
         _data = dict()
 
         for key, val in data.items():
@@ -82,13 +83,13 @@ class Launch_item_lineManager(TreeAuditModelManager):
             Item.objects.update_or_create(id=child_id, defaults=dict(props=item_props))
         return data_res
 
-    @staticmethod
-    def section_num(section):
+    @classmethod
+    def section_num(cls, section):
         sorted_section = {"Документация": 0, "Комплексы": 1, "Сборочные единицы": 2, "Детали": 3, "Стандартные изделия": 4, "Прочие изделия": 5, "Материалы": 6, "Комплекты": 7}
         return sorted_section.get(section)
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'child_id': record.child.id if record.child else None,
@@ -134,8 +135,8 @@ class Launch_item_lineManager(TreeAuditModelManager):
         }
         return res
 
-    @staticmethod
-    def getIcon(record):
+    @classmethod
+    def getIcon(cls, record):
         if record.isFolder:
             return 'folder_256.png'
         elif record.section:
@@ -164,7 +165,7 @@ class Launch_item_line(AuditModel):
     parent = ForeignKeyProtect(Item, related_name='Launch_item_parent')
     added_parent = ForeignKeyProtect('self', related_name='Launch_item_added_parent', null=True, blank=True)
     child = ForeignKeyProtect(Item, related_name='Launch_item_child')
-    item_line = ForeignKeyProtect(Item_line, null=True, blank=True)
+    item_line = ForeignKeySetNull(Item_line, null=True, blank=True)
     launch = ForeignKeyProtect(Launches)
 
     SPC_CLM_FORMAT = ForeignKeyProtect(Document_attributes, verbose_name='Формат', related_name='Launch_SPC_CLM_FORMAT', null=True, blank=True)
