@@ -23,14 +23,14 @@ class launch_item_prod_order_per_launch_viewQuerySet(AuditQuerySet):
 
 class launch_item_prod_order_per_launch_viewManager(AuditManager):
 
-    @staticmethod
-    def get_buffer_oddment_value(value):
+    @classmethod
+    def get_buffer_oddment_value(cls, value):
         if value is None:
             return None
         return blinkString(text=DecimalToStr(value), blink=True if value < 0 else False, bold=True, color='green' if value > 0 else 'red')
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'child_id': record.child.id,
             'deliting': record.deliting,
