@@ -4,7 +4,7 @@ from bitfield import BitField
 from django.db.models import CheckConstraint, Q, F, UniqueConstraint, TextField, DecimalField, PositiveIntegerField
 
 from isc_common.fields.code_field import JSONFieldIVC
-from isc_common.fields.related import ForeignKeyProtect
+from isc_common.fields.related import ForeignKeyProtect, ForeignKeySetNull
 from isc_common.models.audit import AuditModel, AuditManager, AuditQuerySet
 from isc_common.models.tree_audit import TreeAuditModelManager
 from isc_common.number import DelProps
@@ -21,15 +21,15 @@ class Launch_item_refsQuerySet(AuditQuerySet):
 
 class Launch_item_refsManager(AuditManager):
 
-    @staticmethod
-    def props():
+    @classmethod
+    def props(cls):
         return BitField(flags=(
             ('used', 'Доступность в данной производственной спецификации'),  # 1
             ('changed', 'Изменилось в данной производственной спецификации'),  # 2
         ), default=1, db_index=True)
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'props': record.props._value,
@@ -47,7 +47,7 @@ class Launch_item_refs(AuditModel):
     child = ForeignKeyProtect(Item, related_name='launch_child')
     item_full_name = TextField(db_index=True)
     item_full_name_obj = JSONFieldIVC()
-    item_refs = ForeignKeyProtect(Item_refs, blank=True, null=True)
+    item_refs = ForeignKeySetNull(Item_refs, blank=True, null=True)
     launch = ForeignKeyProtect(Launches)
     parent = ForeignKeyProtect(Item, related_name='launch_parent', blank=True, null=True)
     props = Launch_item_refsManager.props()
