@@ -3,6 +3,7 @@ import logging
 from django.db import transaction
 from django.db.models import BigIntegerField, BooleanField, PositiveIntegerField
 
+from isc_common.common import formirovanie, route_made_error
 from isc_common.common.functions import delete_dbl_spaces
 from isc_common.fields.code_field import CodeField
 from isc_common.fields.name_field import NameField
@@ -27,8 +28,8 @@ class Launch_item_viewQuerySet(TreeAuditModelQuerySet):
 
 
 class Launch_item_viewManager(AuditManager):
-    @staticmethod
-    def find_item(item, launch):
+    @classmethod
+    def find_item(cls, item, launch):
         if isinstance(item, int):
             item = Item.objects.get(id=item)
         elif not isinstance(item, Item):
@@ -56,15 +57,15 @@ class Launch_item_viewManager(AuditManager):
 
         return [item for item in item_query]
 
-    @staticmethod
-    def check_launch(launch):
+    @classmethod
+    def check_launch(cls, launch):
         from django.conf import settings
         if not settings.DEBUG:
-            if launch.status.code != 'formirovanie':
-                raise Exception('''Редактирование допускается только при статусе "Формирование"''')
+            if launch.status.code not in [formirovanie, route_made_error]:
+                raise Exception(f'В состоянии {launch.status.name} редактирование не допускается.')
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'STMP_1_id': record.STMP_1.id if record.STMP_1 else None,
@@ -106,18 +107,28 @@ class Launch_item_viewManager(AuditManager):
         return data
 
     def deleteFromRequest(self, request, removed=None, ):
+        from kaf_pas.production.models.launch_item_refs import Launch_item_refs
+        from kaf_pas.production.models.launch_item_line import Launch_item_line
+
         request = DSRequest(request=request)
+        data = request.get_data()
+        records = data.get('records')
+
         res = 0
-        tuple_ids = request.get_tuple_ids()
         with transaction.atomic():
-            for id, mode in tuple_ids:
-                if mode == 'hide':
-                    super().filter(id=id).soft_delete()
-                elif mode == 'visible':
-                    super().filter(id=id).soft_restore()
-                else:
-                    Launch_item_viewManager.check_launch(launch=Launch_item_view.objects.get(id=id).launch)
-                    qty, _ = super().filter(id=id).delete()
+            for record in records:
+                launch = Launch_item_refs.objects.get(id=record.get('item_refs_id')).launch
+
+                Launch_item_viewManager.check_launch(launch=launch)
+                qty, _ = Launch_item_refs.objects.filter(id=record.get('item_refs_id')).delete()
+                res += qty
+
+                qty, _ = Launch_item_line.objects.filter(
+                    child_id=record.get('id'),
+                    parent_id=record.get('parent_id'),
+                    launch = launch
+                ).delete()
+
                 res += qty
         return res
 
@@ -126,14 +137,14 @@ class Launch_item_viewManager(AuditManager):
 
 
 class Launch_item_view(Hierarcy):
+    STMP_1 = ForeignKeyProtect(Document_attributes, verbose_name='Наименование изделия', related_name='STMP_1_view_launch', null=True, blank=True)
+    STMP_2 = ForeignKeyProtect(Document_attributes, verbose_name='Обозначение изделия', related_name='STMP_2_view_launch', null=True, blank=True)
     document = ForeignKeyProtect(Documents, verbose_name='Документ', null=True, blank=True)
     item_refs_id = BigIntegerField()
     launch = ForeignKeySetNull(Launches, related_name='production_launch', null=True, blank=True)
     props = Item_add.get_prop_field()
     relevant = NameField()
     section = CodeField(null=True, blank=True)
-    STMP_1 = ForeignKeyProtect(Document_attributes, verbose_name='Наименование изделия', related_name='STMP_1_view_launch', null=True, blank=True)
-    STMP_2 = ForeignKeyProtect(Document_attributes, verbose_name='Обозначение изделия', related_name='STMP_2_view_launch', null=True, blank=True)
     version = PositiveIntegerField(null=True, blank=True)
     where_from = NameField()
 
