@@ -84,8 +84,8 @@ class Launch_operations_materialManager(CommonManagetWithLookUpFieldsManager):
                 res += qty
         return res
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'operation_material_id': record.operation_material.id if record.operation_material else None,
