@@ -55,8 +55,8 @@ class Launch_operation_resourcesQuerySet(CommonManagetWithLookUpFieldsQuerySet):
 
 class Launch_operation_resourcesManager(CommonManagetWithLookUpFieldsManager):
 
-    @staticmethod
-    def refresh_resource(apps=None, schema_editor=None):
+    @classmethod
+    def refresh_resource(cls, apps=None, schema_editor=None):
         key = 'Launch_operation_resourcesManager.refresh_resource'
         settings.LOCKS.acquire(key)
         sql_text = '''select  launch_operationitem_id, count(*)
@@ -172,8 +172,8 @@ class Launch_operation_resourcesManager(CommonManagetWithLookUpFieldsManager):
                 res += qty
         return res
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'operation_resources_id': record.operation_resources.id if record.operation_resources else None,
