@@ -32,8 +32,8 @@ class LaunchesQuerySet(BaseRefQuerySet):
 class LaunchesManager(BaseRefManager):
     launches_ext = Launches_ext()
 
-    @staticmethod
-    def props():
+    @classmethod
+    def props(cls):
         return BitField(flags=(
             ('addload', 'запуск в несколько приемов'),
         ), default=0, db_index=True)
@@ -44,8 +44,10 @@ class LaunchesManager(BaseRefManager):
         data = request.get_data()
         if isinstance(data, dict):
             records = data.get('records')
+            props = data.get('props')
+
             if isinstance(records, list):
-                return self.launches_ext._getQtyChilds(records=records)
+                return self.launches_ext._getQtyChilds(records=records, props=props)
 
     def createFromRequest(self, request):
         request = DSRequest(request=request)
@@ -157,15 +159,13 @@ class LaunchesManager(BaseRefManager):
                                     settings.LOCKS.release(key)
                                     raise ProgressDroped(progress_deleted)
 
-                            # qty1, _ = super().filter(id=launch.id).delete()
-
                             if launch.demand is not None:
                                 launch.demand.status = status_demand_otkr
                                 launch.demand.save()
 
-                            if launch.demand is not None:
-                                launch.demand.status = settings.PROD_OPERS_STACK.DEMAND_OTMENA
-                                launch.demand.save()
+                            # if launch.demand is not None:
+                            #     launch.demand.status = settings.PROD_OPERS_STACK.DEMAND_OTMENA
+                            #     launch.demand.save()
                             launch.delete()
 
                             if Launches.objects.filter(parent_id=id).count() == 0:
@@ -206,8 +206,8 @@ class LaunchesManager(BaseRefManager):
 
                     res += qty + qty1
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'code': record.code,
@@ -258,6 +258,16 @@ class Launches(BaseRefHierarcy):
         else:
             return []
 
+    @property
+    def all_launches(self):
+        child_launches = self.child_launches
+        if len(child_launches) == 0:
+            return [self]
+        else:
+            child_launches.append(self)
+            return child_launches
+
+
     def __str__(self):
         return f"ID:{self.id}, " \
                f"code: {self.code}, " \
