@@ -1,13 +1,13 @@
 import logging
 
 from isc_common import delAttr
-from isc_common.common import red
+from isc_common.common import red, sht, otkryt
 
 logger = logging.getLogger(__name__)
 
 
 class Launches_ext:
-    def _getQtyChilds(self, records):
+    def _getQtyChilds(self, records, props=1):
         from django.db import connection
         from kaf_pas.ckk.models.item_qty import Item_qty
 
@@ -37,6 +37,7 @@ class Launches_ext:
                     Item_qty.objects.create(
                         child_id=record.get('id'),
                         parent_id=record.get('parent_id'),
+                        props=props,
                         qty=qty
                     )
         return dict(qty=res)
@@ -279,17 +280,17 @@ class Launches_ext:
         from kaf_pas.production.models.ready_2_launch_ext import Item_refs_Stack
         from kaf_pas.production.models.launches_view import Launches_viewManager
 
-        edizm_shtuka = Ed_izm.objects.get(code='шт')
+        edizm_shtuka = Ed_izm.objects.get(code=sht)
 
         if mode == 'update':
-            if demand is not None:
+            if demand is not None and item is None:
                 item_query = Launches.objects.filter(demand=demand, status__code='formirovanie')
                 item_count = item_query.count()
                 if item_count > 0:
                     settings.LOCKS.release(key)
                     raise Exception(f'{demand.code} от {DateToStr(demand.lastmodified)} уже включен в данный запуск.')
 
-        if demand is not None:
+        if demand is not None and item is None:
             cnt = Launches.objects.filter(demand=demand).count() + 1
             child_code = f'{demand.code}/{cnt}'
         else:
@@ -299,9 +300,9 @@ class Launches_ext:
         logger.debug(f'cnt: {cnt}')
         # logger.debug(f'child_code: {child_code}')
 
-        if demand is not None:
-            where_clause = f'where is_bit_on(props, 0) = true \n' \
-                           f'-- and is_bit_on(props, 1) = true \n' \
+        if demand is not None and item is None:
+            where_clause = f'where is_bit_on(props, 1) = true \n' \
+                           f'-- and is_bit_on(props, 0) = true \n' \
                            f'and parent_id != {p_id}'
 
             cntAll = Item_refs.objects.get_descendants_count(
@@ -309,8 +310,8 @@ class Launches_ext:
                 where_clause=where_clause,
             )
         else:
-            where_clause = f'where is_bit_on(props, 0) = true \n' \
-                           f'-- and is_bit_on(props, 1) = true \n'
+            where_clause = f'where is_bit_on(props, 1) = true \n' \
+                           f'-- and is_bit_on(props, 0) = true \n'
 
             cntAll = Item_refs.objects.get_descendants_count(
                 id=item.id,
@@ -336,13 +337,13 @@ class Launches_ext:
             settings.LOCKS.release(key)
             raise Exception(f'Unknown mode: {mode}')
 
-        if demand is not None:
+        if demand is not None and item is None:
             message = blinkString(f'Формирование производственной спецификации: <br>Запуск № {code}, <br>Заказ № {demand.code} от {DateToStr(demand.date)} ({cntAll} позиций.)', bold=True, blink=False)
         else:
             message = blinkString(f'Формирование производственной спецификации: <br>Запуск № {child_code}, от {DateToStr(date)} <br>Изделие: {item.item_name} ({cntAll} позиций.)</pre>', bold=True, blink=False)
 
         with managed_progress(
-                id=f'demand_{demand.id}_{user.id}' if demand is not None else f'demand_{item.id}_{user.id}',
+                id=f'demand_{demand.id}_{user.id}' if demand is not None and item is None else f'demand_{item.id}_{user.id}',
                 qty=cntAll,
                 user=user.id,
                 message=message,
@@ -356,7 +357,7 @@ class Launches_ext:
 
                 progress.except_func = except_func
 
-                qty = demand.qty if demand is not None else qty
+                qty = demand.qty if demand is not None and item is None else qty
 
                 if mode == 'add':
                     if parentlaunch is None:
@@ -382,7 +383,7 @@ class Launches_ext:
                 items_refs_qty_stack = Stack()
                 items_refs_not_used = Stack()
 
-                if demand is not None:
+                if demand is not None and item is None:
                     items_refs_stack.add_parents(id=demand.precent_item.item.id)
                     item_ref_query = Item_refs.objects.get_descendants(
                         id=demand.precent_item.item.id,
@@ -398,7 +399,11 @@ class Launches_ext:
                     )
 
                 for item_ref in item_ref_query:
-                    if item_ref.props.used.is_set == False or items_refs_not_used.exists(lambda x: item_ref.parent.id):
+                    logger.debug('\n//////////////////////////')
+                    logger.debug(f'\nparent: {item_ref.parent.item_name if item_ref.parent else None}, child: {item_ref.child.item_name}')
+                    logger.debug('\n//////////////////////////')
+
+                    if item_ref.props.used.is_set is False or items_refs_not_used.exists(lambda x: x == item_ref.parent.id):
                         items_refs_not_used.push(item_ref.child.id)
                         continue
 
@@ -410,21 +415,23 @@ class Launches_ext:
                         # logger.debug(f'item_line: {item_line}')
 
                     except Item_line.DoesNotExist:
-                        if demand is not None:
+                        if demand is not None and item is None:
                             settings.LOCKS.release(key)
                             raise Exception(blinkString(text=f'Для : PARENT_ID: {item_ref.parent.id if item_ref.parent else None} CHILD_ID: {item_ref.child.id} {items_refs_stack.get_full_path} не найдена строка детализации.', bold=True, blink=False))
 
                     if item_line is not None:
-                        count = self.get_count(
-                            item_line=item_line,
-                            qty=demand.qty if demand is not None else qty,
-                            level=item_ref.level,
-                            get_full_path=items_refs_stack.get_full_path,
-                            items_refs_qty_stack=items_refs_qty_stack
-                        )
+                        count = None
+                        if item_line.section != 'Документация':
+                            count = self.get_count(
+                                item_line=item_line,
+                                qty=demand.qty if demand is not None and item is None else qty,
+                                level=item_ref.level,
+                                get_full_path=items_refs_stack.get_full_path,
+                                items_refs_qty_stack=items_refs_qty_stack
+                            )
 
-                        _count_per_one = StrToNumber(item_line.SPC_CLM_COUNT.value_str) if count is not None and item_line.section != 'Документация' else 0
-                        _count = StrToNumber(count.value_str) if count is not None and item_line.section != 'Документация' else 0
+                        _count_per_one = StrToNumber(item_line.SPC_CLM_COUNT.value_str) if count is not None else 0
+                        _count = StrToNumber(count.value_str) if count is not None else 0
 
                         if items_refs_qty_stack.exists(lambda x: x[0] == item_ref.level and x[1] == item_ref.child.id) == False:
                             items_refs_qty_stack.push((item_ref.level, item_ref.child.id, _count))
@@ -433,9 +440,6 @@ class Launches_ext:
                         _count_per_one = 1
 
                     # start_time = time.clock()
-                    logger.debug('//////////////////////////')
-                    logger.debug(f'parent: {item_ref.parent.item_name if item_ref.parent else None}, child: {item_ref.child.item_name}, qrt: {_count}, qty_per_one: {_count_per_one}')
-                    logger.debug('//////////////////////////')
 
                     launch_item_refs, created = Launch_item_refs.objects.get_or_create(
                         child=item_ref.child,
@@ -451,10 +455,8 @@ class Launches_ext:
                     )
 
                     if created:
-                        # logger.debug(f'Created: {created} launch_item_refs :  {launch_item_refs}')
+                        logger.debug(f'Created: {created} launch_item_refs :  {launch_item_refs}')
                         # logger_timing.debug(f'launch_item_refs Time: {time.clock() - start_time}')
-                        pass
-
                     else:
                         launch_item_refs.replication_factor += 1
                         launch_item_refs.save()
@@ -495,13 +497,12 @@ class Launches_ext:
 
                         if created:
                             logger.debug(f'Created : launch_item_line :  {launch_item_line}')
-                            pass
                         else:
                             logger.debug(f'Existed : launch_item_line :  {launch_item_line}')
 
                     section = launch_item_line.section if launch_item_line is not None else 'Нет'
                     if item_ref.parent:
-                        if first_step == False and demand is not None:
+                        if first_step == False and demand is not None and item is None:
                             self.rec_operations_data(
                                 item=item_ref.parent,
                                 section=section,
@@ -525,7 +526,7 @@ class Launches_ext:
                         settings.LOCKS.release(key)
                         raise ProgressDroped(progress_deleted)
 
-                if demand is not None:
+                if demand is not None and item is None:
                     demand.status = settings.PROD_OPERS_STACK.DEMAND_LAUNCHED
                     demand.save()
                 settings.LOCKS.release(key)
@@ -577,7 +578,7 @@ class Launches_ext:
                 key = f'LaunchesManager.make_launch_{demand_id}'
                 settings.LOCKS.acquire(key)
                 for demand in Demand.objects.filter(id=demand_id):
-                    if demand.status.code != 'otkryt':
+                    if demand.status.code != otkryt:
                         demand_view = Demand_view.objects.get(id=demand.id)
                         if demand_view.launch_qty == 0:
                             demand.status = settings.PROD_OPERS_STACK.DEMAND_OTKR
