@@ -68,8 +68,8 @@ class Operation_def_materialManager(CommonManagetWithLookUpFieldsManager):
             res.append(_res)
         return res
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'operation_id': record.operation.id,
