@@ -172,8 +172,8 @@ class Operation_def_resourcesManager(AuditManager):
                 rec_defaults(operation=operation_id, operation_resource=operation_resource)
             return res
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'operation_id': record.operation.id,
@@ -198,8 +198,8 @@ class Operation_def_resourcesManager(AuditManager):
         }
         return DelProps(res)
 
-    @staticmethod
-    def props():
+    @classmethod
+    def props(cls):
         return BitField(flags=(
             ('rec_default', 'Записать ресурс по умолчанию на все операции на которых нет ресурсов'),  # 1
         ), default=0, db_index=True)
