@@ -68,8 +68,8 @@ class Operation_materialManager(CommonManagetWithLookUpFieldsManager):
             res.append(_res)
         return res
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'operationitem_id': record.operationitem.id,
