@@ -60,8 +60,8 @@ class OR_Wrapper(Wrapper):
 
 class Operation_resourcesManager(CommonManagetWithLookUpFieldsManager):
 
-    @staticmethod
-    def refresh_resource(apps=None, schema_editor=None):
+    @classmethod
+    def refresh_resource(cls, apps=None, schema_editor=None):
         key = 'Operation_resourcesManager.refresh_resource'
         settings.LOCKS.acquire(key)
         sql_text = '''select  operationitem_id, count(*)
@@ -166,8 +166,8 @@ class Operation_resourcesManager(CommonManagetWithLookUpFieldsManager):
         res = super().filter(id=data.get('id')).update(**_data)
         return res
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'operationitem_id': record.operationitem.id if record.operationitem else None,
