@@ -8,7 +8,7 @@ from django.forms import model_to_dict
 
 from isc_common import delAttr, setAttr, Wrapper
 from isc_common.fields.description_field import DescriptionField
-from isc_common.fields.related import ForeignKeyProtect
+from isc_common.fields.related import ForeignKeyProtect, ForeignKeyCascade
 from isc_common.http.DSRequest import DSRequest
 from isc_common.managers.common_managet_with_lookup_fields import CommonManagetWithLookUpFieldsQuerySet, CommonManagetWithLookUpFieldsManager
 from isc_common.models.base_ref import Hierarcy
@@ -62,26 +62,26 @@ class OI_Wrapper(Wrapper):
 
 class Operations_itemManager(CommonManagetWithLookUpFieldsManager):
 
-    @staticmethod
-    def refreshRows(ids):
+    @classmethod
+    def refreshRows(cls,ids):
         if isinstance(ids, int):
             ids = [ids]
         records = [Operations_itemManager.getRecord(record) for record in Operations_item.objects.filter(id__in=ids)]
         WebSocket.row_refresh_grid(grid_id=settings.GRID_CONSTANTS.refresh_production_operations_grid_row, records=records)
 
-    @staticmethod
-    def fullRows(suffix=''):
+    @classmethod
+    def fullRows(cls, suffix=''):
         WebSocket.full_refresh_grid(grid_id=f'{settings.GRID_CONSTANTS.refresh_production_operations_grid}{suffix}')
 
-    @staticmethod
-    def props():
+    @classmethod
+    def props(cls):
         return BitField(flags=(
             ('created', 'Операция добавлена'),  # 1
             ('updated', 'Операция изменена'),  # 2
         ), default=0, db_index=True)
 
-    @staticmethod
-    def refresh_num1():
+    @classmethod
+    def refresh_num1(cls):
         key = 'Operations_itemManager.refresh_num1'
         settings.LOCKS.acquire(key)
         cnt = 0
@@ -98,19 +98,19 @@ class Operations_itemManager(CommonManagetWithLookUpFieldsManager):
         settings.LOCKS.release(key)
         return cnt
 
-    @staticmethod
-    def refresh_num(apps, schema_editor):
+    @classmethod
+    def refresh_num(cls, apps, schema_editor):
         Operations_itemManager.refresh_num1()
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'operation_id': record.operation.id,
             'operation__code': record.operation.code,
             'operation__name': record.operation.name,
-            'operation__full_name': record.operation.full_name,
-            'operation__full_name_real': record.operation.full_name,
+            'operation__full_name': record.operation.fullname,
+            'operation__full_name_real': record.operation.fullname,
             'operation__description': record.operation.description,
             'ed_izm_id': record.ed_izm.id if record.ed_izm else None,
             'ed_izm__code': record.ed_izm.code if record.ed_izm else None,
@@ -137,9 +137,9 @@ class Operations_itemManager(CommonManagetWithLookUpFieldsManager):
         from kaf_pas.production.models.operation_def_resources import Operation_def_resources
         from kaf_pas.production.models.operation_resources import Operation_resources
 
-        query = Operation_def_resources.objects.filter(operation=operationitem.operation)
-        if query.count() > 1:
-            raise Exception('К данному типу операции по-умолчанию привязано более одного ресурса или места выполнения.')
+        # query = Operation_def_resources.objects.filter(operation=operationitem.operation)
+        # if query.count() == 0:
+        #     raise Exception('К данному типу операции не привязан ресурс или место выполнения.')
 
         for operation_def_resource in Operation_def_resources.objects.filter(operation=operationitem.operation):
             Operation_resources.objects.get_or_create(
@@ -184,11 +184,11 @@ class Operations_itemManager(CommonManagetWithLookUpFieldsManager):
                                 setAttr(__res, 'operation__full_name', _res.operation.full_name)
                                 res.append(__res)
 
-        Operations_itemManager.fullRows()
+        Operations_itemManager.fullRows(suffix=f"_item_{data.item_id[0]}")
         return res
 
-    @staticmethod
-    def check_tansport_operations(operations_item, operation_item=None, errors_set=None):
+    @classmethod
+    def check_tansport_operations(cls, operations_item, operation_item=None, errors_set=None):
         from kaf_pas.production.models.operation_resources import Operation_resources
         from kaf_pas.production.models.operation_def_resources import Operation_def_resources
 
@@ -201,8 +201,8 @@ class Operations_itemManager(CommonManagetWithLookUpFieldsManager):
                     operation_resources.operationitem.delete()
                     errors_set.add(f'К операции: {operation_resources.operationitem.operation.full_name} не привязано местоположение. И была удалана.')
                     return False
-                else:
-                    raise Exception(f'Товарная позиция: {operation_item.item.item_name}, операция: {operation_resources.operation.full_name} не привязано местоположение.')
+                # else:
+                #     raise Exception(f'Товарная позиция: {operation_item.item.item_name}, операция: {operation_resources.operation.full_name} не привязано местоположение.')
             elif operation_resources.location.is_workshop:
                 if errors_set is not None:
                     def_operation_resources = Operation_def_resources.objects.get(operation=operation_resources.operationitem.operation)
@@ -250,8 +250,8 @@ class Operations_itemManager(CommonManagetWithLookUpFieldsManager):
                             operation_before.delete()
                             errors_set.add(f'К операции: {operation_before.operation.full_name} не привязано местоположение. И была удалана.')
                             cont = False
-                        else:
-                            raise Exception(f'Товарная позиция: {operation_item.item.item_name}, операция: {operation_before.operation.full_name} не привязано местоположение.')
+                        # else:
+                        #     raise Exception(f'Товарная позиция: {operation_item.item.item_name}, операция: {operation_before.operation.full_name} не привязано местоположение.')
 
                 try:
                     operation_resources_after = Operation_resources.objects.get(operationitem=operation_after)
@@ -266,78 +266,78 @@ class Operations_itemManager(CommonManagetWithLookUpFieldsManager):
                             operation_after.delete()
                             errors_set.add(f'К операции: {operation_after.operation.full_name} не привязано местоположение. И была удалана.')
                             cont = False
-                        else:
-                            raise Exception(f'Товарная позиция: {operation_item.item.item_name}, операция: {operation_after.operation.full_name} не привязано местоположение.')
+                        # else:
+                        #     raise Exception(f'Товарная позиция: {operation_item.item.item_name}, операция: {operation_after.operation.full_name} не привязано местоположение.')
 
-                if cont == True:
-                    if operation_resources.location != operation_resources_before.location or \
-                            operation_resources.location_fin != operation_resources_after.location:
-
-                        using_another_place = Operations_item.objects.filter(operation=operation_item.operation).exclude(id=operation_item.id).count() > 0
-
-                        if using_another_place:
-                            try:
-                                operation_def_resources = Operation_def_resources.objects.get(
-                                    operation=operation_item.operation,
-                                    resource=operation_resources.resource,
-                                    location=operation_resources_before.location,
-                                    location_fin=operation_resources_after.location,
-                                )
-                                operation = operation_def_resources.operation
-                                logger.debug(f'exists operation: {operation}')
-                            except Operation_def_resources.DoesNotExist:
-                                operation, created = Operations.objects.get_or_create(
-                                    code=f'{operation_resources_before.location.code}-{operation_resources_after.location.code}',
-                                    defaults=dict(
-                                        name='Транспортировка',
-                                        props=Operations.props.transportation,
-                                        parent=operation_item.operation.parent
-                                    )
-                                )
-
-                                if created:
-                                    logger.debug(f'created operation: {operation}')
-
-                                    Operation_def_resources.objects.create(
-                                        operation=operation,
-                                        resource=operation_resources.resource,
-                                        location=operation_resources_before.location,
-                                        location_fin=operation_resources_after.location,
-                                    )
-                                else:
-                                    Operation_def_resources.objects. \
-                                        filter(operation=operation). \
-                                        update(
-                                        resource=operation_resources.resource,
-                                        location=operation_resources_before.location,
-                                        location_fin=operation_resources_after.location,
-                                    )
-
-                            operation_resources.location = operation_resources_before.location
-                            operation_resources.location_fin = operation_resources_after.location
-                            operation_resources.save()
-
-                            logger.debug(f'operation_item.operation: {operation_item.operation}')
-                            logger.debug(f'operation: {operation}')
-                            if len([a for a in operations_item if a.operation == operation]) == 0:
-                                operation_item.operation = operation
-                                operation_item.save()
-                            else:
-                                operation_item.delete()
-                        else:
-                            operation_resources.location = operation_resources_before.location
-                            operation_resources.location_fin = operation_resources_after.location
-                            operation_resources.save()
-
-                            # operation = operation_item.operation
-                            # operation.code = f'{operation_resources_before.location.code}-{operation_resources_after.location.code}'
-                            # operation.name = 'Транспортировка'
-                            # operation.save()
-
-                            operation_locations_def = Operation_def_resources.objects.get(operation=operation_item.operation)
-                            operation_locations_def.location = operation_resources_before.location
-                            operation_locations_def.location_fin = operation_resources_after.location
-                            operation_locations_def.save()
+                # if cont == True:
+                #     if operation_resources.location != operation_resources_before.location or \
+                #             operation_resources.location_fin != operation_resources_after.location:
+                #
+                #         using_another_place = Operations_item.objects.filter(operation=operation_item.operation).exclude(id=operation_item.id).count() > 0
+                #
+                #         if using_another_place:
+                #             try:
+                #                 operation_def_resources = Operation_def_resources.objects.get(
+                #                     operation=operation_item.operation,
+                #                     resource=operation_resources.resource,
+                #                     location=operation_resources_before.location,
+                #                     location_fin=operation_resources_after.location,
+                #                 )
+                #                 operation = operation_def_resources.operation
+                #                 logger.debug(f'exists operation: {operation}')
+                #             except Operation_def_resources.DoesNotExist:
+                #                 operation, created = Operations.objects.get_or_create(
+                #                     code=f'{operation_resources_before.location.code}-{operation_resources_after.location.code}',
+                #                     defaults=dict(
+                #                         name='Транспортировка',
+                #                         props=Operations.props.transportation,
+                #                         parent=operation_item.operation.parent
+                #                     )
+                #                 )
+                #
+                #                 if created:
+                #                     logger.debug(f'created operation: {operation}')
+                #
+                #                     Operation_def_resources.objects.create(
+                #                         operation=operation,
+                #                         resource=operation_resources.resource,
+                #                         location=operation_resources_before.location,
+                #                         location_fin=operation_resources_after.location,
+                #                     )
+                #                 else:
+                #                     Operation_def_resources.objects. \
+                #                         filter(operation=operation). \
+                #                         update(
+                #                         resource=operation_resources.resource,
+                #                         location=operation_resources_before.location,
+                #                         location_fin=operation_resources_after.location,
+                #                     )
+                #
+                #             operation_resources.location = operation_resources_before.location
+                #             operation_resources.location_fin = operation_resources_after.location
+                #             operation_resources.save()
+                #
+                #             logger.debug(f'operation_item.operation: {operation_item.operation}')
+                #             logger.debug(f'operation: {operation}')
+                #             if len([a for a in operations_item if a.operation == operation]) == 0:
+                #                 operation_item.operation = operation
+                #                 operation_item.save()
+                #             else:
+                #                 operation_item.delete()
+                #         else:
+                #             operation_resources.location = operation_resources_before.location
+                #             operation_resources.location_fin = operation_resources_after.location
+                #             operation_resources.save()
+                #
+                #             # operation = operation_item.operation
+                #             # operation.code = f'{operation_resources_before.location.code}-{operation_resources_after.location.code}'
+                #             # operation.name = 'Транспортировка'
+                #             # operation.save()
+                #
+                #             operation_locations_def = Operation_def_resources.objects.get(operation=operation_item.operation)
+                #             operation_locations_def.location = operation_resources_before.location
+                #             operation_locations_def.location_fin = operation_resources_after.location
+                #             operation_locations_def.save()
 
     def updateFromRequest(self, request):
 
@@ -411,7 +411,7 @@ class Operations_itemManager(CommonManagetWithLookUpFieldsManager):
                             delAttr(v, 'dropIndex')
                             delAttr(v, 'dropPosition')
                             for k1, v1 in v.items():
-                                if k1.find('_') == -1:
+                                if k1.find('_') == -1 or k1.find('_id') != -1:
                                     setAttr(data1, k1, v1)
                             setAttr(data1, '_operation', 'update')
                             res = super().filter(id=v.get('id')).update(**data1)
@@ -421,7 +421,7 @@ class Operations_itemManager(CommonManagetWithLookUpFieldsManager):
                             # data.num = operation_item.num
                             data1 = dict()
                             for k1, v1 in data.dict.items():
-                                if k1.find('_') == -1:
+                                if k1.find('_') == -1 or k1.find('_id') != -1:
                                     setAttr(data1, k1, v1)
 
                             delAttr(data1, 'id')
@@ -436,7 +436,13 @@ class Operations_itemManager(CommonManagetWithLookUpFieldsManager):
                     res = super().filter(id=data.id).update(**_data)
 
                 settings.LOCKS.release(key)
-                Operations_itemManager.fullRows()
+                if data.num == data_old.num:
+                    Operations_itemManager.refreshRows(data.id)
+                else:
+                    try:
+                        Operations_itemManager.fullRows(suffix=f"_item_{Operations_item.objects.get(id=data.id).item.id}")
+                    except Operations_item.DoesNotExist:
+                        pass
                 return res
         except Exception as ex:
             settings.LOCKS.release(key)
@@ -450,7 +456,7 @@ class Operations_item(Hierarcy):
     item = ForeignKeyProtect(Item)
     num = PositiveIntegerField(null=True, blank=True)
     old_num = PositiveIntegerField(db_index=True, null=True, blank=True)
-    operation = ForeignKeyProtect(Operations)
+    operation = ForeignKeyCascade(Operations)
     props = Operations_itemManager.props()
     qty = PositiveIntegerField(null=True, blank=True)
 
