@@ -18,8 +18,8 @@ class Operations_templateQuerySet(BaseRefQuerySet):
 
 class Operations_templateManager(BaseRefManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'code': record.code,
