@@ -25,8 +25,8 @@ class Operations_template_detailQuerySet(CommonManagetWithLookUpFieldsQuerySet):
 
 class Operations_template_detailManager(CommonManagetWithLookUpFieldsManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'operation_id': record.operation.id,
