@@ -47,8 +47,8 @@ class Operations_template_resourceQuerySet(CommonManagetWithLookUpFieldsQuerySet
 
 class Operations_template_resourceManager(CommonManagetWithLookUpFieldsManager):
 
-    @staticmethod
-    def refresh_resource(apps=None, schema_editor=None):
+    @classmethod
+    def refresh_resource(cls, apps=None, schema_editor=None):
         key = 'Operations_template_resourceManager.refresh_resource'
         settings.LOCKS.acquire(key)
         sql_text = '''select  template_id, count(*)
@@ -141,8 +141,8 @@ class Operations_template_resourceManager(CommonManagetWithLookUpFieldsManager):
         res = super().filter(id=data.get('id')).update(**_data)
         return res
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'template_id': record.template.id if record.template else None,
