@@ -17,8 +17,8 @@ class Operations_viewQuerySet(CommonManagetWithLookUpFieldsQuerySet):
 
 class Operations_viewManager(CommonManagetWithLookUpFieldsManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             "code": record.code,
             "description": record.description,
