@@ -17,8 +17,8 @@ class Ready_2_launch_detailQuerySet(AuditQuerySet):
 
 class Ready_2_launch_detailManager(AuditManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'item_full_name': record.item_full_name,
