@@ -4,6 +4,7 @@ from django.db import connection
 
 from isc_common import Stack
 from isc_common.common import blinkString, red, black
+from kaf_pas.production.models import p_id
 
 logger = logging.getLogger(__name__)
 
@@ -206,17 +207,17 @@ class Ready_2_launch_ext:
             options.push('Включена опция проверки количества.')
 
         if demand is not None:
-            demand_str = f'<h/3>Оценка готовности к запуску: Заказ № {demand.code} от {DateToStr(demand.date)}</h3>'
             key = f'Ready_2_launchManager.make_{demand.id}'
             settings.LOCKS.acquire(key)
             qty = Item_refs.objects.get_descendants_count(
                 id=demand.precent_item.item.id,
             )
+            demand_str = f'<h/3>Оценка готовности к запуску: Заказ № {demand.code} от {DateToStr(demand.date)} ({qty} позиций)</h3>'
         else:
-            demand_str = f'<h/3>Оценка готовности к запуску: Изделие {item.item_name}</h3>'
             key = f'Ready_2_launchManager.make_{item.id}'
             settings.LOCKS.acquire(key)
             qty = Item_refs.objects.get_descendants_count(id=item.id)
+            demand_str = f'<h/3>Оценка готовности к запуску: Изделие {item.item_name} ({qty} позиций)</h3>'
 
         logger.debug(f'Counted: {qty}')
         with managed_progress(
@@ -253,8 +254,10 @@ class Ready_2_launch_ext:
 
                 for item_ref in descendant_request:
 
-                    # if item_ref.parent and item_ref.parent.id == p_id:
-                    #     raise Exception(f'Оценить готовность у {item_ref.child.item_name} невозможно, потому как это позиция находится под {item_ref.parent.item_name}.')
+                    if item_ref.parent is not None and item_ref.parent.id == p_id:
+                        item_ref.delete()
+                        continue
+                        # raise Exception(f'Оценить готовность у {item_ref.child.item_name} невозможно, потому как это позиция находится под {item_ref.parent.item_name}.')
 
                     notes = Stack()
 
@@ -272,10 +275,12 @@ class Ready_2_launch_ext:
                         inner_lines_count = Item_line.objects.filter(parent=item_ref.child).count()
 
                         if inner_descendant_count != inner_lines_count:
-                            notes.push(blinkString(text=f'Количетво дочерних узлов в дереве состава изделия ({inner_descendant_count}), не равно количеству строк детализации ({inner_lines_count}).', blink=False, color=black, bold=False))
-                            if not item_full_name:
-                                item_full_name_obj = items_refs_stack.get_full_path_obj
-                                item_full_name = items_refs_stack.get_full_path
+                            if inner_descendant_count < inner_lines_count:
+                                cnt_not1 += 1
+                                notes.push(blinkString(text=f'Количетво дочерних узлов в дереве состава изделия ({inner_descendant_count}), не равно количеству строк детализации ({inner_lines_count}).', blink=False, color=red, bold=True))
+                                if not item_full_name:
+                                    item_full_name_obj = items_refs_stack.get_full_path_obj
+                                    item_full_name = items_refs_stack.get_full_path
 
                         item_line = None
                         if qty == 1:
@@ -286,27 +291,29 @@ class Ready_2_launch_ext:
 
                         if section and section != 'Документация':
                             if item_ref.props.used.is_set == False or items_not_used.exists(lambda x: x == item_ref.parent.id):
-                                notes.push(blinkString(text='Позиция не используется.', blink=False, color=black, bold=False))
+                                notes.push(blinkString(text='Позиция не используется.', blink=False, color=black, bold=True))
                                 if not item_full_name:
                                     item_full_name_obj = items_refs_stack.get_full_path_obj
                                     item_full_name = items_refs_stack.get_full_path
 
                             elif IsBitOn(props, 6) and item_line is not None and not item_line.qty:
                                 cnt_not1 += 1
-                                notes.push(blinkString(text='Не указано количество.', blink=False, color=red, bold=False))
+                                notes.push(blinkString(text='Не указано количество.', blink=False, color=red, bold=True))
                                 if not item_full_name:
                                     item_full_name_obj = items_refs_stack.get_full_path_obj
                                     item_full_name = items_refs_stack.get_full_path
                         else:
-                            notes.push(blinkString(text='Найдена документация, требует проверки правильности принадлежности.', blink=False, color=black, bold=False))
+                            text = 'Найдена документация, требует проверки правильности принадлежности.'
+                            logger.info(text)
+                            notes.push(blinkString(text=text, blink=False, color=black, bold=True))
                             if not item_full_name:
                                 item_full_name_obj = items_refs_stack.get_full_path_obj
                                 item_full_name = items_refs_stack.get_full_path
 
                     except Item_line.DoesNotExist:
-                        if demand is not None:
-                            cnt_not += 1
-                            notes.push(blinkString(text='Не входит в детализацию.', blink=False, color=red, bold=False))
+                        cnt_not += 1
+                        if Item_line.checkVariants(parent=item_ref.parent, child=item_ref.child) == 0:
+                            notes.push(blinkString(text='Не входит в детализацию.', blink=False, color=red, bold=True))
                             if not item_full_name:
                                 item_full_name_obj = items_refs_stack.get_full_path_obj
                                 item_full_name = items_refs_stack.get_full_path
@@ -316,14 +323,14 @@ class Ready_2_launch_ext:
                             if operations_cnt == 0:
                                 if IsBitOn(props, 5):
                                     cnt_not += 1
-                                    notes.push(blinkString(text='Не указаны операции.', blink=False, color=red, bold=False))
+                                    notes.push(blinkString(text='Не указаны операции.', blink=False, color=red, bold=True))
                                     item_full_name_obj = items_refs_stack.get_full_path_obj
                                     item_full_name = items_refs_stack.get_full_path
                             else:
                                 for operations_item in Operations_item.objects.filter(item=item_ref.child):
                                     if IsBitOn(props, 0) and not operations_item.qty:
                                         cnt_not1 = 1
-                                        notes.push(blinkString(text=f'Операция: {operations_item.operation.full_name} не указана длительность.', blink=False, color=red, bold=False))
+                                        notes.push(blinkString(text=f'Операция: {operations_item.operation.full_name} не указана длительность.', blink=False, color=red, bold=True))
                                         if not item_full_name:
                                             item_full_name_obj = items_refs_stack.get_full_path_obj
                                             item_full_name = items_refs_stack.get_full_path
@@ -331,7 +338,7 @@ class Ready_2_launch_ext:
                                     if IsBitOn(props, 1):
                                         if not operations_item.num:
                                             cnt_not1 = 1
-                                            notes.push(blinkString(text=f'Операция: {operations_item.operation.full_name} не указан № п/п.', blink=False, color=red, bold=False))
+                                            notes.push(blinkString(text=f'Операция: {operations_item.operation.full_name} не указан № п/п.', blink=False, color=red, bold=True))
                                             if not item_full_name:
                                                 item_full_name_obj = items_refs_stack.get_full_path_obj
                                                 item_full_name = items_refs_stack.get_full_path
@@ -340,7 +347,7 @@ class Ready_2_launch_ext:
                                         operation_material_cnt = Operation_material.objects.filter(operationitem=operations_item).count()
                                         if operation_material_cnt == 0:
                                             cnt_not1 = 1
-                                            notes.push(blinkString(text=f'Операция: {operations_item.operation.full_name} не указаны материалы или стандартные изделия.', blink=False, color=red, bold=False))
+                                            notes.push(blinkString(text=f'Операция: {operations_item.operation.full_name} не указаны материалы или стандартные изделия.', blink=False, color=red, bold=True))
                                             if not item_full_name:
                                                 item_full_name_obj = items_refs_stack.get_full_path_obj
                                                 item_full_name = items_refs_stack.get_full_path
@@ -349,7 +356,7 @@ class Ready_2_launch_ext:
                                         operation_resources_query = Operation_resources.objects.filter(operationitem=operations_item)
                                         if operation_resources_query.count() == 0:
                                             cnt_not1 = 1
-                                            notes.push(blinkString(text=f'Операция: {operations_item.operation.full_name} не указан ресурс либо место выполнения.', blink=False, color=red, bold=False))
+                                            notes.push(blinkString(text=f'Операция: {operations_item.operation.full_name} не указан ресурс либо место выполнения.', blink=False, color=red, bold=True))
                                             if not item_full_name:
                                                 item_full_name_obj = items_refs_stack.get_full_path_obj
                                                 item_full_name = items_refs_stack.get_full_path
@@ -365,7 +372,7 @@ class Ready_2_launch_ext:
                                                         operation_def_resources = Operation_def_resources.objects.get(operation=operations_item.operation)
                                                         if operation_def_resources.location_fin is None and operation_def_resources.resource_fin is None:
                                                             cnt_not1 = 1
-                                                            notes.push(blinkString(text=f'Операция: {operations_item.operation.full_name} не указан конечный ресурс либо место выполнения.', blink=False, color=red, bold=False))
+                                                            notes.push(blinkString(text=f'Операция: {operations_item.operation.full_name} не указан конечный ресурс либо место выполнения.', blink=False, color=red, bold=True))
                                                             if not item_full_name:
                                                                 item_full_name_obj = items_refs_stack.get_full_path_obj
                                                                 item_full_name = items_refs_stack.get_full_path
@@ -376,14 +383,14 @@ class Ready_2_launch_ext:
 
                                                     except Operation_def_resources.DoesNotExist:
                                                         cnt_not1 = 1
-                                                        notes.push(blinkString(text=f'Операция: {operations_item.operation.full_name} не указан конечный ресурс либо место выполнения.', blink=False, color=red, bold=False))
+                                                        notes.push(blinkString(text=f'Операция: {operations_item.operation.full_name} не указан конечный ресурс либо место выполнения.', blink=False, color=red, bold=True))
                                                         if not item_full_name:
                                                             item_full_name_obj = items_refs_stack.get_full_path_obj
                                                             item_full_name = items_refs_stack.get_full_path
 
                                     if IsBitOn(props, 4) and not operations_item.ed_izm:
                                         cnt_not1 = 1
-                                        notes.push(blinkString(text=f'Операция: {operations_item.operation.full_name} не указана единица измерения.', blink=False, color=red, bold=False))
+                                        notes.push(blinkString(text=f'Операция: {operations_item.operation.full_name} не указана единица измерения.', blink=False, color=red, bold=True))
                                         if not item_full_name:
                                             item_full_name_obj = items_refs_stack.get_full_path_obj
                                             item_full_name = items_refs_stack.get_full_path
