@@ -17,8 +17,8 @@ class ResourceQuerySet(BaseRefQuerySet, CommonManagetWithLookUpFieldsQuerySet):
 
 
 class ResourceManager(CommonManagetWithLookUpFieldsManager):
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'code': record.code,
