@@ -77,8 +77,8 @@ class Resource_usersManager(AuditManager):
 
             return res
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'user_id': record.user.id,
