@@ -38,6 +38,20 @@ def Launches_Fetch_4_Production_values(request):
             ),
             status=RPCResponseConstant.statusSuccess).response)
 
+@JsonResponseWithException()
+def Launches_Fetch_4_Production_values_Ext(request):
+    return JsonResponse(
+        DSResponse(
+            request=request,
+            data=Launches_view.objects.
+                select_related('demand', 'status', 'item').
+                filter().
+                get_range_rows_4_Production_values_Ext(
+                request=request,
+                function=Launches_viewManager.getRecord
+            ),
+            status=RPCResponseConstant.statusSuccess).response)
+
 
 @JsonResponseWithException()
 def Launches_Planing_Fetch(request):
