@@ -8,6 +8,7 @@ from isc_common.fields.related import ForeignKeyProtect, ForeignKeyCascade
 from isc_common.http.DSRequest import DSRequest
 from isc_common.managers.common_managet_with_lookup_fields import CommonManagetWithLookUpFieldsManager, CommonManagetWithLookUpFieldsQuerySet
 from isc_common.models.base_ref import BaseRefHierarcy
+from isc_common.number import ToDecimal
 from kaf_pas.sales.models.precent import Precent
 from kaf_pas.sales.models.precent_dogovors import Precent_dogovors
 from kaf_pas.sales.models.precent_items import Precent_items
@@ -29,8 +30,8 @@ class DemandQuerySet(CommonManagetWithLookUpFieldsQuerySet):
 
 class DemandManager(CommonManagetWithLookUpFieldsManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'code': record.code,
@@ -103,9 +104,10 @@ class DemandManager(CommonManagetWithLookUpFieldsManager):
 
                     for precent_item in Precent_items.objects.filter(id=precent_item_id).select_for_update():
                         precent_item = Precent_items_view.objects.get(id=precent_item.id)
-                        qty = precent_item.qty - precent_item.used_qty
-                        if _qty > qty:
-                            raise Exception(f'Нет затребованного количества. В наличии {qty}, затребовано: {_qty}')
+                        if precent_item.qty is not None:
+                            qty = precent_item.qty - ToDecimal(precent_item.used_qty)
+                            if _qty > qty:
+                                raise Exception(f'Нет затребованного количества. В наличии {qty}, затребовано: {_qty}')
                         res = super().create(**_data)
                         setAttr(_data, 'id', res.id)
 
@@ -120,8 +122,8 @@ class DemandManager(CommonManagetWithLookUpFieldsManager):
                                     edizm=precent_materials.edizm,
                                 )
 
-            return _data
             settings.LOCKS.release(key)
+            return _data
         except Exception as ex:
             settings.LOCKS.release(key)
             raise ex
@@ -140,25 +142,13 @@ class DemandManager(CommonManagetWithLookUpFieldsManager):
             delAttr(_data, 'tail_qty')
             delAttr(_data, 'enabled')
             delAttr(_data, 'parent')
-            delAttr(_data, 'precent__code')
-            delAttr(_data, 'precent__date')
-            delAttr(_data, 'precent__precent_type_id')
-            delAttr(_data, 'precent__precent_type__name')
-            delAttr(_data, 'precent_dogovor__code')
-            delAttr(_data, 'precent_dogovor__name')
-            delAttr(_data, 'precent_dogovor__date')
-            delAttr(_data, 'precent_dogovor__dogovor__customer__name')
-            delAttr(_data, 'precent_item__STMP_1_id')
-            delAttr(_data, 'precent_item__STMP_1__value_str')
-            delAttr(_data, 'precent_item__STMP_2_id')
-            delAttr(_data, 'precent_item__STMP_2__value_str')
-            delAttr(_data, 'status__code')
-            delAttr(_data, 'status__name')
             delAttr(_data, 'isFolder')
             delAttr(_data, 'year')
             delAttr(_data, 'month')
             delAttr(_data, 'month_name')
             delAttr(_data, 'groupParentId')
+            _data = self.delete_underscore_element(_data)
+            _data = self.delete_dbl_underscore_element(_data)
             super().filter(id=data.get('id')).update(**_data)
 
         return data
