@@ -19,8 +19,8 @@ class Demand_materialsQuerySet(CommonManagetWithLookUpFieldsQuerySet):
 
 class Demand_materialsManager(CommonManagetWithLookUpFieldsManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             "id": record.id,
             'material_askon_id': record.material_askon.id if record.material_askon else None,
