@@ -7,6 +7,7 @@ from isc_common.fields.code_field import CodeField
 from isc_common.fields.related import ForeignKeyProtect, ForeignKeyCascade
 from isc_common.managers.common_managet_with_lookup_fields import CommonManagetWithLookUpFieldsManager, CommonManagetWithLookUpFieldsQuerySet
 from isc_common.models.base_ref import BaseRefHierarcy
+from isc_common.number import ToDecimal, ToStr, ToInt
 from kaf_pas.kd.models.document_attributes import Document_attributes
 from kaf_pas.sales.models.precent import Precent
 from kaf_pas.sales.models.precent_dogovors import Precent_dogovors
@@ -22,99 +23,85 @@ class Demand_viewQuerySet(CommonManagetWithLookUpFieldsQuerySet):
 
 class Demand_viewManager(CommonManagetWithLookUpFieldsManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
-            'id': record.id,
             'code': record.code,
-            'name': record.name,
-            'description': record.description,
-            'parent': record.parent.id if record.parent else None,
             'date': record.date,
             'date_sign': record.precent.date_sign,
-            'qty': record.qty,
-            'launch_qty': record.launch_qty,
-            'tail_qty': record.tail_qty,
-            'qty_for_launch': record.qty_for_launch,
+            'deliting': record.deliting,
+            'description': record.description,
+            'editing': record.editing,
+            'enabled': IsBitOff(record.status.props, 0),
+            'id': record.id,
+            'isFolder': record.isFolder,
+            'launch_qty': ToInt(record.launch_qty),
+            'name': record.name,
+            'parent': record.parent.id if record.parent else None,
             'parent_id': record.parent.id if record.parent else None,
-
-            'precent_id': record.precent.id,
             'precent__code': record.precent.code,
             'precent__date': record.precent.date,
-
-            'precent__precent_type_id': record.precent.precent_type.id,
             'precent__precent_type__name': record.precent.precent_type.name,
-
-            'precent_dogovor_id': record.precent_dogovor.id,
+            'precent__precent_type_id': record.precent.precent_type.id,
             'precent_dogovor__code': record.precent_dogovor.dogovor.code,
-            'precent_dogovor__name': record.precent_dogovor.dogovor.name,
             'precent_dogovor__date': record.precent_dogovor.dogovor.date,
-
             'precent_dogovor__dogovor__customer__name': record.precent_dogovor.dogovor.customer.name,
-
-            'precent_item_id': record.precent_item.id,
-            'precent_item__STMP_1_id': record.precent_item.item.STMP_1.id if record.precent_item.item.STMP_1 else None,
+            'precent_dogovor__name': record.precent_dogovor.dogovor.name,
+            'precent_dogovor_id': record.precent_dogovor.id,
+            'precent_id': record.precent.id,
             'precent_item__STMP_1__value_str': record.precent_item.item.STMP_1.value_str if record.precent_item.item.STMP_1 else None,
-            'precent_item__STMP_2_id': record.precent_item.item.STMP_2.id if record.precent_item.item.STMP_2 else None,
+            'precent_item__STMP_1_id': record.precent_item.item.STMP_1.id if record.precent_item.item.STMP_1 else None,
             'precent_item__STMP_2__value_str': record.precent_item.item.STMP_2.value_str if record.precent_item.item.STMP_2 else None,
-
-            'status_id': record.status.id,
+            'precent_item__STMP_2_id': record.precent_item.item.STMP_2.id if record.precent_item.item.STMP_2 else None,
+            'precent_item_id': record.precent_item.id,
+            'qty': record.qty,
+            'qty_for_launch': ToInt(record.qty_for_launch),
             'status__code': record.status.code,
             'status__name': record.status.name,
-
-            'isFolder': record.isFolder,
-            'enabled': IsBitOff(record.status.props, 0),
-
-            'editing': record.editing,
-            'deliting': record.deliting,
+            'status_id': record.status.id,
+            'tail_qty': ToInt(record.tail_qty),
         }
         return res
 
-    @staticmethod
-    def getRecord1(record):
+    @classmethod
+    def getRecord1(cls, record):
+        enabled = record.tail_qty > 0
+
         res = {
-            'id': record.id,
             'code': record.code,
-            'name': record.name,
-            'description': record.description,
-            'parent': record.parent.id if record.parent else None,
             'date': record.date,
             'date_sign': record.precent.date_sign,
-            'qty': record.qty,
-            'launch_qty': record.launch_qty,
-            'tail_qty': record.tail_qty,
-            'qty_for_launch': record.qty_for_launch,
+            'deliting': record.deliting,
+            'description': record.description,
+            'editing': record.editing,
+            'enabled' : enabled,
+            'id': record.id,
+            'isFolder': record.isFolder,
+            'launch_qty': ToInt(record.launch_qty),
+            'name': record.name,
+            'parent': record.parent.id if record.parent else None,
             'parent_id': record.parent.id if record.parent else None,
-            'enabled' : record.launch_qty < record.tail_qty,
-
-            'precent_id': record.precent.id,
             'precent__code': record.precent.code,
             'precent__date': record.precent.date,
-
-            'precent__precent_type_id': record.precent.precent_type.id,
             'precent__precent_type__name': record.precent.precent_type.name,
-
-            'precent_dogovor_id': record.precent_dogovor.id,
+            'precent__precent_type_id': record.precent.precent_type.id,
             'precent_dogovor__code': record.precent_dogovor.dogovor.code,
-            'precent_dogovor__name': record.precent_dogovor.dogovor.name,
             'precent_dogovor__date': record.precent_dogovor.dogovor.date,
-
             'precent_dogovor__dogovor__customer__name': record.precent_dogovor.dogovor.customer.name,
-
-            'precent_item_id': record.precent_item.id,
-            'precent_item__STMP_1_id': record.precent_item.item.STMP_1.id if record.precent_item.item.STMP_1 else None,
+            'precent_dogovor__name': record.precent_dogovor.dogovor.name,
+            'precent_dogovor_id': record.precent_dogovor.id,
+            'precent_id': record.precent.id,
             'precent_item__STMP_1__value_str': record.precent_item.item.STMP_1.value_str if record.precent_item.item.STMP_1 else None,
-            'precent_item__STMP_2_id': record.precent_item.item.STMP_2.id if record.precent_item.item.STMP_2 else None,
+            'precent_item__STMP_1_id': record.precent_item.item.STMP_1.id if record.precent_item.item.STMP_1 else None,
             'precent_item__STMP_2__value_str': record.precent_item.item.STMP_2.value_str if record.precent_item.item.STMP_2 else None,
-
-            'status_id': record.status.id,
+            'precent_item__STMP_2_id': record.precent_item.item.STMP_2.id if record.precent_item.item.STMP_2 else None,
+            'precent_item_id': record.precent_item.id,
+            'qty': record.qty,
+            'qty_for_launch': ToInt(record.qty_for_launch),
             'status__code': record.status.code,
             'status__name': record.status.name,
-
-            'isFolder': record.isFolder,
-
-            'editing': record.editing,
-            'deliting': record.deliting,
+            'status_id': record.status.id,
+            'tail_qty': ToInt(record.tail_qty),
         }
         return res
 
