@@ -13,8 +13,8 @@ class Dogovor_typesQuerySet(BaseRefQuerySet):
 
 class Dogovor_typesManager(BaseRefManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'code': record.code,
