@@ -11,8 +11,8 @@ class Precent_item_typesQuerySet(BaseRefQuerySet):
 
 class Precent_item_typesManager(BaseRefManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'code': record.code,
