@@ -14,8 +14,8 @@ class Status_demandQuerySet(BaseRefQuerySet):
 
 class Status_demandManager(StatusBaseRefManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'code': record.code,
