@@ -14,8 +14,8 @@ class StatusDogovorQuerySet(BaseRefQuerySet):
 
 class StatusDogovorManager(StatusBaseRefManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'code': record.code,
