@@ -17,8 +17,8 @@ class ContantsQuerySet(BaseRefQuerySet):
 
 class ContantsManager(BaseRefManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'code': record.code,
